@@ -23,14 +23,14 @@
 
 package ch.kuramo.javie.api;
 
-import javax.media.opengl.GL;
+import javax.media.opengl.GL2;
 
 public enum ColorMode {
 
-	RGBA8			(GL.GL_RGBA8      , GL.GL_UNSIGNED_BYTE ,  4),
-	RGBA16			(GL.GL_RGBA16     , GL.GL_UNSIGNED_SHORT,  8),
-	RGBA16_FLOAT	(GL.GL_RGBA16F_ARB, GL.GL_FLOAT         , 16),
-	RGBA32_FLOAT	(GL.GL_RGBA32F_ARB, GL.GL_FLOAT         , 16);
+	RGBA8			(GL2.GL_RGBA8  , GL2.GL_UNSIGNED_BYTE ,  4),
+	RGBA16			(GL2.GL_RGBA16 , GL2.GL_UNSIGNED_SHORT,  8),
+	RGBA16_FLOAT	(GL2.GL_RGBA16F, GL2.GL_FLOAT         , 16),
+	RGBA32_FLOAT	(GL2.GL_RGBA32F, GL2.GL_FLOAT         , 16);
 
 
 	public final int glInternalFormat;
