@@ -24,9 +24,16 @@
 package ch.kuramo.javie.api.services;
 
 import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IShaderSourceFactory;
 
 public interface IShaderRegistry {
 
+	IShaderProgram getProgram(String name);
+
 	IShaderProgram getProgram(Class<?> clazz, String name);
 
+	IShaderProgram getProgram(IShaderSourceFactory sourceFactory);
+
+	void addShader(IShaderSourceFactory sourceFactory);
+
 }
