@@ -120,6 +120,8 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 
 	private ShowConsoleViewAction showConsoleViewAction;
 
+	private IWorkbenchAction preferencesAction;
+
 	private IWorkbenchAction aboutAction;
 
 	private MenuManager recentProjectsMenu;
@@ -220,6 +222,9 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		showConsoleViewAction = new ShowConsoleViewAction(window);
 		register(showConsoleViewAction);
 
+		preferencesAction = ActionFactory.PREFERENCES.create(window);
+		register(preferencesAction);
+
 		aboutAction = ActionFactory.ABOUT.create(window);
 		register(aboutAction);
 
@@ -343,8 +348,12 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		}
 		windowMenu.add(showProjectViewAction);
 		windowMenu.add(showConsoleViewAction);
+		windowMenu.add(new Separator());
+		windowMenu.add(preferencesAction);
 
 		// Help
+		helpMenu.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
+		helpMenu.add(new Separator());
 		helpMenu.add(aboutAction);
 	}
 
