@@ -31,6 +31,7 @@ import javax.media.opengl.GLCapabilities;
 import org.eclipse.core.commands.operations.IOperationHistory;
 import org.eclipse.core.commands.operations.LinearUndoEnforcer;
 import org.eclipse.core.runtime.Platform;
+import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.application.IWorkbenchConfigurer;
@@ -45,7 +46,7 @@ import ch.kuramo.javie.core.services.GLGlobal;
 
 public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {
 
-	public void initialize(IWorkbenchConfigurer configurer) {
+	public void initialize(final IWorkbenchConfigurer configurer) {
 		super.initialize(configurer);
 
 		configurer.setSaveAndRestore(true);
@@ -54,18 +55,33 @@ public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {
 		history.addOperationApprover(new LinearUndoEnforcer());
 
 
-		if (Platform.getOS().equals(Platform.OS_WIN32)) {
-			GLGlobal glGlobal = InjectorHolder.getInjector().getInstance(GLGlobal.class);
+		String os = Platform.getOS();
+		boolean win32 = os.equals(Platform.OS_WIN32);
+		boolean macosx = os.equals(Platform.OS_MACOSX);
 
-			// TODO これらの値を環境設定で変更できるようにする。
-			int poolSize = 20;
-			GLCapabilities canvasCap = glGlobal.getCanvasCapabilities();
-			canvasCap.setDoubleBuffered(true);
+		final GLGlobal glGlobal = InjectorHolder.getInjector().getInstance(GLGlobal.class);
+		if (glGlobal.getInitError() == null) {
+			boolean intel = glGlobal.isIntel();
 
-			glGlobal.enterPoolMode(poolSize);
-			glGlobal.setCanvasCapabilities(canvasCap);
+			if (win32 || (macosx && intel)) {
+				// TODO これらの値を環境設定で変更できるようにする。
+				int poolSize = (win32 && intel) ? 8 : 20;
+				GLCapabilities canvasCap = glGlobal.getCanvasCapabilities();
+				canvasCap.setDoubleBuffered(win32);
 
-			GLCanvasFactory.getFactory().enterPoolMode(poolSize);
+				glGlobal.enterPoolMode(poolSize);
+				glGlobal.setCanvasCapabilities(canvasCap);
+
+				GLCanvasFactory.getFactory().enterPoolMode(poolSize);
+			}
+		} else {
+			configurer.getWorkbench().getDisplay().asyncExec(new Runnable() {
+				public void run() {
+					MessageDialog.openError(null,
+							"OpenGLの初期化に失敗しました", glGlobal.getInitError());
+					configurer.getWorkbench().close();
+				}
+			});
 		}
 
 		Initializer.initialize();
