@@ -26,6 +26,9 @@ package ch.kuramo.javie.app;
 import java.io.File;
 import java.util.Set;
 
+import org.eclipse.core.commands.operations.IOperationHistoryListener;
+import org.eclipse.core.commands.operations.IUndoableOperation;
+import org.eclipse.core.commands.operations.OperationHistoryEvent;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.swt.graphics.Point;
@@ -34,12 +37,14 @@ import org.eclipse.ui.IMemento;
 import org.eclipse.ui.IViewReference;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.application.ActionBarAdvisor;
 import org.eclipse.ui.application.IActionBarConfigurer;
 import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
 import org.eclipse.ui.application.WorkbenchWindowAdvisor;
 
 import ch.kuramo.javie.app.actions.NewProjectAction;
+import ch.kuramo.javie.app.project.ModifyLayerCompSettingsOperation;
 import ch.kuramo.javie.app.project.ProjectEvent;
 import ch.kuramo.javie.app.project.ProjectEventHub;
 import ch.kuramo.javie.app.project.ProjectListener;
@@ -51,7 +56,7 @@ import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.MediaItem;
 
 public class ApplicationWorkbenchWindowAdvisor
-		extends WorkbenchWindowAdvisor implements ProjectListener {
+		extends WorkbenchWindowAdvisor implements ProjectListener, IOperationHistoryListener {
 
 	private static final String DONE_SAVE_CONFIRMATION = "DONE_SAVE_CONFIRMATION";
 
@@ -77,11 +82,15 @@ public class ApplicationWorkbenchWindowAdvisor
 		configurer.setInitialSize(new Point(800, 600));
 		configurer.setShowMenuBar(true);
 		configurer.setShowCoolBar(false);
-		configurer.setShowStatusLine(false);
+        configurer.setShowStatusLine(true);
+        configurer.setShowProgressIndicator(true);
 		configurer.setTitle("Javie");
 	}
 
 	public void postWindowCreate() {
+		PlatformUI.getWorkbench().getOperationSupport()
+				.getOperationHistory().addOperationHistoryListener(this);
+
 		ProjectEventHub.getHub().addProjectListener(this);
 
 		Shell shell = getWindowConfigurer().getWindow().getShell();
@@ -124,6 +133,9 @@ public class ApplicationWorkbenchWindowAdvisor
 		}
 
 		ProjectEventHub.getHub().removeProjectListener(this);
+
+		PlatformUI.getWorkbench().getOperationSupport()
+				.getOperationHistory().removeOperationHistoryListener(this);
 	}
 
 	private void updateWindowTitle(ProjectManager pm) {
@@ -188,4 +200,43 @@ public class ApplicationWorkbenchWindowAdvisor
 		}
 	}
 
+	public void historyNotification(OperationHistoryEvent event) {
+		IWorkbenchWindow window = getWindowConfigurer().getWindow();
+		ProjectManager pm = ProjectManager.forWorkbenchWindow(window);
+		if (pm == null) {
+			// プロジェクトが初期化される前または破棄された後にここに来ることがあるのか？
+			return;
+		}
+
+		IUndoableOperation op = event.getOperation();
+
+		if (op instanceof ModifyLayerCompSettingsOperation && op.hasContext(pm.getUndoContext())) {
+			String compItemId = ((ModifyLayerCompSettingsOperation) op).getCompositionItemId();
+			IWorkbenchPage page = window.getActivePage();
+
+			switch (event.getEventType()) {
+				case OperationHistoryEvent.ABOUT_TO_EXECUTE:
+				case OperationHistoryEvent.ABOUT_TO_REDO:
+				case OperationHistoryEvent.ABOUT_TO_UNDO:
+					LayerCompositionView compView = UIUtil.findView(page, LayerCompositionView.ID, compItemId);
+					if (compView != null) {
+						UIUtil.hideView(page, compView);
+					}
+
+					MediaPlayerView playerView = UIUtil.findView(page, MediaPlayerView.ID, compItemId);
+					if (playerView != null) {
+						UIUtil.hideView(page, playerView);
+					}
+					break;
+
+				case OperationHistoryEvent.DONE:
+				case OperationHistoryEvent.REDONE:
+				case OperationHistoryEvent.UNDONE:
+					UIUtil.showView(page, LayerCompositionView.ID, compItemId, IWorkbenchPage.VIEW_ACTIVATE);
+					UIUtil.showView(page, MediaPlayerView.ID, compItemId, IWorkbenchPage.VIEW_VISIBLE);
+					break;
+			}
+		}
+	}
+
 }
