@@ -43,8 +43,8 @@ import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.services.EffectRegistry;
 import ch.kuramo.javie.core.services.ProjectElementFactory;
-import ch.kuramo.javie.core.services.ShaderBuildException;
-import ch.kuramo.javie.core.services.ShaderBuilder;
+import ch.kuramo.javie.core.services.ShaderRegistry;
+import ch.kuramo.javie.core.services.ShaderRegistryException;
 
 import com.google.inject.Inject;
 
@@ -66,7 +66,7 @@ public class Initializer {
 	private ProjectElementFactory _elementFactory;
 
 	@Inject
-	private ShaderBuilder _shaderBuilder;
+	private ShaderRegistry _shaderRegistry;
 
 
 	Initializer() {
@@ -82,11 +82,11 @@ public class Initializer {
 			ClassLoader cl = Project.class.getClassLoader();
 			_effectRegistry.searchClasses(db, cl);
 			_elementFactory.searchClasses(db, cl);
-			_shaderBuilder.buildShaders(db, cl);
+			_shaderRegistry.scanShaders(db, cl);
 
 		} catch (IOException e) {
 			throw new JavieRuntimeException(e);
-		} catch (ShaderBuildException e) {
+		} catch (ShaderRegistryException e) {
 			throw new JavieRuntimeException(e);
 		}
 	}
@@ -128,7 +128,7 @@ public class Initializer {
 					ClassLoader cl = clazz.getClassLoader();
 					_effectRegistry.searchClasses(db, cl);
 					_elementFactory.searchClasses(db, cl);
-					_shaderBuilder.buildShaders(db, cl);
+					_shaderRegistry.scanShaders(db, cl);
 
 				} catch (Exception e) {
 					_logger.warn("can't load JaviePlugin: " + id, e);
