@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app;
 
+import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.List;
@@ -113,13 +114,13 @@ public class Perspective implements IPerspectiveFactory {
 	}
 
 	private static String perspectiveId(ProjectManager pm) {
-		String path;
+		File file;
 		try {
-			path = pm.getFile().getCanonicalPath();
+			file = pm.getFile().getCanonicalFile();
 		} catch (IOException e) {
-			path = pm.getFile().getAbsolutePath();
+			file = pm.getFile().getAbsoluteFile();
 		}
-		return ID + "." + pm.getProject().getId() + "." + path;
+		return ID + "." + pm.getProject().getId() + "." + file.toURI().toASCIIString();
 	}
 
 	private static void closeOther(IWorkbenchPage page, IPerspectiveDescriptor perspective) {
