@@ -31,7 +31,6 @@ import java.io.PipedOutputStream;
 import java.lang.reflect.InvocationTargetException;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
-import java.util.Arrays;
 
 import javax.sound.sampled.AudioFileFormat;
 import javax.sound.sampled.AudioFormat;
@@ -47,7 +46,9 @@ import org.eclipse.swt.widgets.FileDialog;
 import org.eclipse.ui.IWorkbenchWindow;
 
 import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.Time;
+import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.app.CommandIds;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.app.project.ProjectManager;
@@ -59,7 +60,6 @@ import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
-import ch.kuramo.javie.core.services.ArrayPools;
 import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.ProjectDecoder;
 import ch.kuramo.javie.core.services.ProjectEncoder;
@@ -83,7 +83,7 @@ public class WaveOutputAction extends Action {
 	private AudioRenderContext arContext;
 
 	@Inject
-	private ArrayPools _arrayPools;
+	private IArrayPools _arrayPools;
 
 
 	public WaveOutputAction(LayerCompositionView view) {
@@ -206,8 +206,7 @@ public class WaveOutputAction extends Action {
 
 			arContext.activate();
 			try {
-				// TODO これはループの外で良いんだっけ？　良いはずだが自信無し。要確認
-				comp.prepareExpression(arContext.createInitialExpressionScope());
+				comp.prepareExpression(arContext.createInitialExpressionScope(comp));
 
 				long videoFrameNumber = 0;
 				for (long i = 0; i < totalFrames; ) {
@@ -224,6 +223,7 @@ public class WaveOutputAction extends Action {
 					arContext.setAudioMode(audioMode);
 					arContext.setTime(time);
 					arContext.setFrameCount((int) Math.min(chunkFrames, totalFrames-i));
+					arContext.setEvaluationResolution(audioMode.sampleRate/100);
 
 					AudioBuffer ab = comp.renderAudioChunk();
 					try {
@@ -262,11 +262,12 @@ public class WaveOutputAction extends Action {
 			AudioMode audioMode = ab.getAudioMode();
 			int dataLen = ab.getDataLength();
 			int dataLenInBytes = ab.getDataLengthInBytes();
-			byte[] outBuf = _arrayPools.getByteArray(dataLenInBytes);
+			IArray<byte[]> pa = _arrayPools.getByteArray(dataLenInBytes);
+			byte[] outBuf = pa.getArray();
 
 			switch (audioMode.dataType) {
 				case SHORT:
-					ByteBuffer.wrap(outBuf).order(ByteOrder.nativeOrder())
+					ByteBuffer.wrap(outBuf, 0, dataLenInBytes).order(ByteOrder.nativeOrder())
 							.asShortBuffer().put((short[]) ab.getData(), 0, dataLen);
 					break;
 				case INT: {
@@ -292,15 +293,14 @@ public class WaveOutputAction extends Action {
 			}
 
 			out.write(outBuf, 0, dataLenInBytes);
-			_arrayPools.put(outBuf);
+			pa.release();
 		}
 
 		private void writeZero(AudioMode audioMode, int frameCount, OutputStream out) throws IOException {
-			int dataLenInBytes = audioMode.frameSize * frameCount;
-			byte[] outBuf = _arrayPools.getByteArray(dataLenInBytes);
-			Arrays.fill(outBuf, (byte) 0);
-			out.write(outBuf, 0, dataLenInBytes);
-			_arrayPools.put(outBuf);
+			IArray<byte[]> pa = _arrayPools.getByteArray(audioMode.frameSize * frameCount);
+			pa.clear();
+			out.write(pa.getArray(), 0, pa.getLength());
+			pa.release();
 		}
 
 	}
