@@ -25,7 +25,6 @@ package ch.kuramo.javie.app.player;
 
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
-import java.util.Arrays;
 import java.util.concurrent.atomic.AtomicReference;
 
 import javax.sound.sampled.AudioFormat;
@@ -39,14 +38,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.Time;
+import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaItem;
-import ch.kuramo.javie.core.services.ArrayPools;
 import ch.kuramo.javie.core.services.AudioRenderContext;
 
 import com.google.inject.Inject;
@@ -78,7 +78,7 @@ public class AudioThread extends Thread {
 	private AudioRenderContext _arContext;
 
 	@Inject
-	private ArrayPools _arrayPools;
+	private IArrayPools _arrayPools;
 
 
 	public AudioThread(MediaItem mediaItem) throws LineUnavailableException {
@@ -158,8 +158,8 @@ public class AudioThread extends Thread {
 				if (!_muted) {
 					_arContext.reset();
 					_arContext.setAudioMode(audioMode);
-					_arContext.setTime(time);
 					_arContext.setFrameCount(frameCount);
+					_arContext.setEvaluationResolution(audioMode.sampleRate/100);
 
 					if (_mediaItem instanceof CompositionItem) {
 						// TODO 上の input.getDuration() も厳密にはロックする必要がある。
@@ -167,9 +167,9 @@ public class AudioThread extends Thread {
 						try {
 							// TODO prepareExpressionはプロジェクトに構造的な変更があった場合のみ行えばよい。
 							Composition comp = ((CompositionItem) _mediaItem).getComposition();
-							comp.prepareExpression(_arContext.createInitialExpressionScope());
+							comp.prepareExpression(_arContext.createInitialExpressionScope(comp));
 
-							ab = input.getAudioChunk();
+							ab = input.getAudioChunk(time);
 						} catch (Exception e) {
 							_logger.error("error getting audio chunk", e);
 						} finally {
@@ -177,7 +177,7 @@ public class AudioThread extends Thread {
 						}
 					} else {
 						try {
-							ab = input.getAudioChunk();
+							ab = input.getAudioChunk(time);
 						} catch (Exception e) {
 							_logger.error("error getting audio chunk", e);
 						}
@@ -257,11 +257,12 @@ public class AudioThread extends Thread {
 		AudioMode audioMode = ab.getAudioMode();
 		int dataLen = ab.getDataLength();
 		int lineDataLen = _line.getFormat().getFrameSize() * ab.getFrameCount();
-		byte[] lineBuf = _arrayPools.getByteArray(lineDataLen);
+		IArray<byte[]> pa = _arrayPools.getByteArray(lineDataLen);
+		byte[] lineBuf = pa.getArray();
 
 		switch (audioMode.dataType) {
 			case SHORT:
-				ByteBuffer.wrap(lineBuf).order(ByteOrder.nativeOrder())
+				ByteBuffer.wrap(lineBuf, 0, lineDataLen).order(ByteOrder.nativeOrder())
 						.asShortBuffer().put((short[]) ab.getData(), 0, dataLen);
 				break;
 			case INT: {
@@ -298,15 +299,14 @@ public class AudioThread extends Thread {
 		}
 
 		_line.write(lineBuf, 0, lineDataLen);
-		_arrayPools.put(lineBuf);
+		pa.release();
 	}
 
 	private void writeZero(int frameCount) {
-		int lineDataLen = _line.getFormat().getFrameSize() * frameCount;
-		byte[] lineBuf = _arrayPools.getByteArray(lineDataLen);
-		Arrays.fill(lineBuf, (byte) 0);
-		_line.write(lineBuf, 0, lineDataLen);
-		_arrayPools.put(lineBuf);
+		IArray<byte[]> pa = _arrayPools.getByteArray(_line.getFormat().getFrameSize() * frameCount);
+		pa.clear();
+		_line.write(pa.getArray(), 0, pa.getLength());
+		pa.release();
 	}
 
 	public void addPlayerThreadListener(PlayerThreadListener listener) {
