@@ -471,6 +471,8 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 
 	public void handleProjectEvent(ProjectEvent event) {
 		switch (event.type) {
+			case COMPOSITION_SETTINGS_CHANGE:
+			case COMPOSITION_PROPERTY_CHANGE:
 			case LAYER_PROPERTY_CHANGE:
 			case LAYERS_ADD:
 			case LAYERS_REMOVE:
