@@ -35,12 +35,12 @@ import java.util.Map.Entry;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.atomic.AtomicReference;
 
-import javax.media.opengl.DebugGL;
-import javax.media.opengl.GL;
+import javax.media.opengl.DebugGL2;
+import javax.media.opengl.GL2;
 import javax.media.opengl.GLAutoDrawable;
-import javax.media.opengl.GLCanvas;
 import javax.media.opengl.GLContext;
 import javax.media.opengl.GLEventListener;
+import javax.media.opengl.awt.GLCanvas;
 import javax.media.opengl.glu.GLU;
 
 import org.eclipse.core.runtime.ListenerList;
@@ -74,10 +74,12 @@ import ch.kuramo.javie.core.MediaItem;
 import ch.kuramo.javie.core.SolidColorItem;
 import ch.kuramo.javie.core.TimeCode;
 import ch.kuramo.javie.core.VideoBuffer;
+import ch.kuramo.javie.core.misc.AtiIntelLock;
+import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.VideoRenderContext;
 
 import com.google.inject.Inject;
-import com.sun.opengl.util.GLUT;
+import com.sun.opengl.util.gl2.GLUT;
 
 public class VideoCanvas extends Thread implements GLEventListener {
 
@@ -100,9 +102,9 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 	private final GLCanvas _canvas;
 
-	private final GLU _glu = new GLU();
+	private GLU _glu;
 
-	private final GLUT _glut = new GLUT();
+	private GLUT _glut;
 
 	private final AtomicReference<Object[]> _videoBufferAndTimeRef = new AtomicReference<Object[]>();
 
@@ -149,6 +151,13 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	@Inject
 	private VideoRenderContext _vrContext;
 
+	@Inject
+	private GLGlobal _glGlobal;
+
+	private final boolean _intel;
+
+	private final AtiIntelLock _atiIntelLock;
+
 
 	public VideoCanvas(Composite parent, MediaItem mediaItem, TimeKeeper timeKeeper) {
 		super("VideoCanvas: " + mediaItem.getName());
@@ -181,6 +190,9 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		}
 
 		setZoom(1.0);
+
+		_intel = _glGlobal.isIntel();
+		_atiIntelLock = AtiIntelLock.get(_glGlobal);
 	}
 
 	public Control getControl() {
@@ -374,22 +386,32 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	}
 
 	public void init(GLAutoDrawable drawable) {
-		GL gl = drawable.getGL();
+		_atiIntelLock.lock();
+		try {
 
-		gl.glEnable(GL.GL_TEXTURE_RECTANGLE_EXT);
-		gl.glColor4f(1, 1, 1, 1);
+			GL2 gl = drawable.getGL().getGL2();
 
-		// 背景を黒以外にする場合はアルファブレンドを有効にし、blendFuncを次のように設定する。
-		//gl.glEnable(GL.GL_BLEND);
-		//gl.glBlendFunc(GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
+			_glu = GLU.createGLU(gl);
+			_glut = new GLUT();
 
-		gl.glClearColor(0, 0, 0, 1);
-		gl.glClear(GL.GL_COLOR_BUFFER_BIT);
+			gl.glEnable(GL2.GL_TEXTURE_RECTANGLE);
+			gl.glColor4f(1, 1, 1, 1);
 
-		gl.glMatrixMode(GL.GL_MODELVIEW);
-		gl.glLoadIdentity();
+			// 背景を黒以外にする場合はアルファブレンドを有効にし、blendFuncを次のように設定する。
+			//gl.glEnable(GL2.GL_BLEND);
+			//gl.glBlendFunc(GL2.GL_ONE, GL2.GL_ONE_MINUS_SRC_ALPHA);
 
-		_glInitialized = true;
+			gl.glClearColor(0, 0, 0, 1);
+			gl.glClear(GL2.GL_COLOR_BUFFER_BIT);
+
+			gl.glMatrixMode(GL2.GL_MODELVIEW);
+			gl.glLoadIdentity();
+
+			_glInitialized = true;
+
+		} finally {
+			_atiIntelLock.unlock();
+		}
 	}
 
 	public void display(GLAutoDrawable drawable) {
@@ -401,14 +423,16 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			init(drawable);
 		}
 
-		_displaying = true;
-
 		Object[] vbAndTime = null;
+
+		_displaying = true;
+		_atiIntelLock.lock();
 		try {
-			GL gl = drawable.getGL();
+
+			GL2 gl = drawable.getGL().getGL2();
 
 			// 背景を黒以外にする場合に必要。initメソッド内のコメント参照。
-			//gl.glClear(GL.GL_COLOR_BUFFER_BIT);
+			//gl.glClear(GL2.GL_COLOR_BUFFER_BIT);
 
 			vbAndTime = _videoBufferAndTimeRef.getAndSet(null);
 			if (vbAndTime == null) {
@@ -424,24 +448,24 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			int w = imageSize.width;
 			int h = imageSize.height;
 
-			gl.glMatrixMode(GL.GL_PROJECTION);
+			gl.glMatrixMode(GL2.GL_PROJECTION);
 			gl.glLoadIdentity();
 			_glu.gluOrtho2D(0, w, h, 0);
 
 
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vb.getTexture());
 
-			gl.glBegin(GL.GL_QUADS);
+			gl.glBegin(GL2.GL_QUADS);
 			gl.glTexCoord2f(0, 0); gl.glVertex2f(0, 0);
 			gl.glTexCoord2f(w, 0); gl.glVertex2f(w, 0);
 			gl.glTexCoord2f(w, h); gl.glVertex2f(w, h);
 			gl.glTexCoord2f(0, h); gl.glVertex2f(0, h);
 			gl.glEnd();
 
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
 
 			if (_showInfo) {
-				gl.glPushAttrib(GL.GL_ENABLE_BIT | GL.GL_CURRENT_BIT | GL.GL_COLOR_BUFFER_BIT);
+				gl.glPushAttrib(GL2.GL_ENABLE_BIT | GL2.GL_CURRENT_BIT | GL2.GL_COLOR_BUFFER_BIT);
 
 				gl.glLoadIdentity();
 				_glu.gluOrtho2D(0, vp[2], vp[3], 0);
@@ -454,6 +478,8 @@ public class VideoCanvas extends Thread implements GLEventListener {
 			gl.glFinish();
 
 		} finally {
+			_atiIntelLock.unlock();
+
 			if (vbAndTime != null && !_videoBufferAndTimeRef.compareAndSet(null, vbAndTime)) {
 				_oldVideoBuffers.add((VideoBuffer) vbAndTime[0]);
 			}
@@ -462,7 +488,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		}
 	}
 
-	private void drawInfo(GL gl, Time time) {
+	private void drawInfo(GL2 gl, Time time) {
 		List<String> info = new ArrayList<String>();
 
 		VideoBounds bounds = _mediaInput.getVideoFrameBounds();
@@ -505,17 +531,17 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		}
 		infoWidth += 2;
 
-		gl.glEnable(GL.GL_BLEND);
-		gl.glBlendFunc(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA);
+		gl.glEnable(GL2.GL_BLEND);
+		gl.glBlendFunc(GL2.GL_SRC_ALPHA, GL2.GL_ONE_MINUS_SRC_ALPHA);
 		gl.glColor4f(0, 0, 0, 0.4f);
-		gl.glBegin(GL.GL_QUADS);
+		gl.glBegin(GL2.GL_QUADS);
 		gl.glVertex2f(10, 10);
 		gl.glVertex2f(10+infoWidth, 10);
 		gl.glVertex2f(10+infoWidth, 10+infoHeight);
 		gl.glVertex2f(10, 10+infoHeight);
 		gl.glEnd();
 
-		gl.glDisable(GL.GL_BLEND);
+		gl.glDisable(GL2.GL_BLEND);
 		gl.glColor4f(0, 1, 0, 1);
 		int i = 0;
 		for (String s : info) {
@@ -528,8 +554,8 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		// nothing to do
 	}
 
-	public void displayChanged(GLAutoDrawable drawable, boolean modeChanged, boolean deviceChanged) {
-		// nothing to do
+	public void dispose(GLAutoDrawable drawable) {
+		// nothing to do ?
 	}
 
 	public void run() {
@@ -537,22 +563,27 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		try {
 			// TODO DebugGLの使用をやめる。でも当分はこのままにしておく。
 			GLContext glContext = GLContext.getCurrent();
-			glContext.setGL(new DebugGL(glContext.getGL()));
+			glContext.setGL(new DebugGL2(glContext.getGL().getGL2()));
 
-			GL gl = _vrContext.getGL();
+			GL2 gl = _vrContext.getGL().getGL2();
 
 			Time duration = _mediaInput.getDuration();
 			if (duration == null) {
 				RenderResolution resolution = _resolution;
 
-				Time time = TIME0;
 				_vrContext.reset();
 				_vrContext.setRenderResolution(resolution);
 				_vrContext.setColorMode(ColorMode.RGBA8);
+				_vrContext.setFrameDuration(TIME0);
 
 				VideoBuffer vb = null;
 				try {
-					vb = _mediaInput.getVideoFrameImage(time);
+					_atiIntelLock.lock();
+					try {
+						vb = _mediaInput.getVideoFrameImage(TIME0);
+					} finally {
+						_atiIntelLock.unlock();
+					}
 				} catch (Exception e) {
 					_logger.error("error getting video frame", e);
 				} catch (InternalError e) {
@@ -561,15 +592,19 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				}
 
 				if (vb != null) {
-					gl.glFinish();
-
-					setTexParametersForDisplay(vb, resolution, gl);
+					_atiIntelLock.lock();
+					try {
+						setTexParametersForDisplay(vb, resolution, gl);
+						glFinish(gl, vb);
+					} finally {
+						_atiIntelLock.unlock();
+					}
 
 					_videoBufferAndTimeRef.getAndSet(new Object[] { vb, TIME0 });
 					_canvas.repaint();
-					fireThreadRender(time);
+					fireThreadRender(TIME0);
 				}
-				fireThreadEndOfDuration(time);
+				fireThreadEndOfDuration(TIME0);
 
 				synchronized (_monitor) {
 					while (!_finished) {
@@ -644,6 +679,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				_vrContext.reset();
 				_vrContext.setRenderResolution(resolution);
 				_vrContext.setColorMode(ColorMode.RGBA8);
+				_vrContext.setFrameDuration(frameDuration);
 
 				VideoBuffer vb = null;
 
@@ -655,7 +691,12 @@ public class VideoCanvas extends Thread implements GLEventListener {
 						Composition comp = ((CompositionItem) _mediaItem).getComposition();
 						comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
 
-						vb = _mediaInput.getVideoFrameImage(frameTime);
+						_atiIntelLock.lock();
+						try {
+							vb = _mediaInput.getVideoFrameImage(frameTime);
+						} finally {
+							_atiIntelLock.unlock();
+						}
 					} catch (Exception e) {
 						_logger.error("error getting video frame", e);
 					} catch (InternalError e) {
@@ -666,7 +707,12 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					}
 				} else {
 					try {
-						vb = _mediaInput.getVideoFrameImage(frameTime);
+						_atiIntelLock.lock();
+						try {
+							vb = _mediaInput.getVideoFrameImage(frameTime);
+						} finally {
+							_atiIntelLock.unlock();
+						}
 					} catch (Exception e) {
 						_logger.error("error getting video frame", e);
 					} catch (InternalError e) {
@@ -676,7 +722,13 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				}
 
 				if (vb != null) {
-					gl.glFinish();
+					_atiIntelLock.lock();
+					try {
+						setTexParametersForDisplay(vb, resolution, gl);
+						glFinish(gl, vb);
+					} finally {
+						_atiIntelLock.unlock();
+					}
 
 					delay = calcDelay(timeAndBase);
 
@@ -686,8 +738,6 @@ public class VideoCanvas extends Thread implements GLEventListener {
 						delay = TIME0;
 
 					} else {
-						setTexParametersForDisplay(vb, resolution, gl);
-
 						Object[] old = _videoBufferAndTimeRef.getAndSet(new Object[] { vb, frameTime });
 						_canvas.repaint();
 						if (old != null) {
@@ -771,8 +821,26 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		cleanup();
 	}
 
-	private void setTexParametersForDisplay(VideoBuffer vb, RenderResolution resolution, GL gl) {
-		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
+	private void glFinish(GL2 gl, VideoBuffer vb) {
+		if (!_intel) {
+			gl.glFinish();
+			return;
+		}
+
+		// Intel GMAの場合、カラーバッファに何もアタッチされていないとglFinishに失敗する。
+		// (GMA X4500で確認) 
+
+		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, vb.getTexture(), 0);
+
+		gl.glFinish();
+
+		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
+	}
+
+	private void setTexParametersForDisplay(VideoBuffer vb, RenderResolution resolution, GL2 gl) {
+		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, vb.getTexture());
 
 		// フル解像度のときは、拡大したときにテクスチャの補間が効かないようにする。
 		// フル解像度でないときは補間を有効にするが、補間によってエッジ部分が
@@ -781,17 +849,17 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		if (RenderResolution.FULL.equals(resolution)) {
 			// GL_TEXTURE_MAG_FILTER だけ設定すればいいはずだが、
 			// ATIではなぜかダメなようなので MIN/MAG 両方を設定している。
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MIN_FILTER, GL.GL_NEAREST);
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MAG_FILTER, GL.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_NEAREST);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_NEAREST);
 
 		} else {
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR);
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR);
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_S, GL.GL_CLAMP_TO_EDGE);
-			gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_T, GL.GL_CLAMP_TO_EDGE);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_LINEAR);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_LINEAR);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_S, GL2.GL_CLAMP_TO_EDGE);
+			gl.glTexParameteri(GL2.GL_TEXTURE_RECTANGLE, GL2.GL_TEXTURE_WRAP_T, GL2.GL_CLAMP_TO_EDGE);
 		}
 
-		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
+		gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
 	}
 
 	private RenderResolution autoResolution(RenderResolution prevResolution, double avgThreshold) {
