@@ -331,6 +331,14 @@ public class ProjectManager implements IOperationHistoryListener {
 		fireProjectEvent(ProjectEvent.createItemsReparentEvent(this, items, relatedItems));
 	}
 
+	void fireCompositionSettingsChange(Composition comp) {
+		fireProjectEvent(ProjectEvent.createCompositionSettingsChangeEvent(this, comp));
+	}
+
+	void fireCompositionPropertyChange(Composition comp, String property) {
+		fireProjectEvent(ProjectEvent.createCompositionPropertyChangeEvent(this, comp, property));
+	}
+
 	void fireLayerPropertyChange(Layer layer, String property) {
 		fireProjectEvent(ProjectEvent.createLayerPropertyChangeEvent(this, layer, property));
 	}
@@ -544,8 +552,28 @@ public class ProjectManager implements IOperationHistoryListener {
 		}
 	}
 
-	void postShadowOperation(Runnable shadowOperation) {
-		shadowOperationRunner.put(shadowOperation);
+	void postShadowOperation(boolean sync, final Runnable shadowOperation) {
+		if (sync) {
+			final Object monitor = new Object();
+			Runnable wrapper = new Runnable() {
+				public void run() {
+					shadowOperation.run();
+					synchronized (monitor) {
+						monitor.notify();
+					}
+				}
+			};
+			synchronized (monitor) {
+				shadowOperationRunner.put(wrapper);
+				try {
+					monitor.wait();
+				} catch (InterruptedException e) {
+					throw new JavieRuntimeException("unexpected interruption", e);
+				}
+			}
+		} else {
+			shadowOperationRunner.put(shadowOperation);
+		}
 	}
 
 	public boolean isDirty() {
