@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app.views;
 
+import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -39,6 +40,7 @@ import org.eclipse.core.runtime.ListenerList;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.GroupMarker;
+import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.util.LocalSelectionTransfer;
@@ -51,6 +53,8 @@ import org.eclipse.jface.viewers.TreePath;
 import org.eclipse.jface.viewers.TreeSelection;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.viewers.TreeViewerColumn;
+import org.eclipse.jface.viewers.Viewer;
+import org.eclipse.jface.viewers.ViewerFilter;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.dnd.DND;
 import org.eclipse.swt.dnd.DragSourceEvent;
@@ -62,6 +66,11 @@ import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.dnd.TreeDragSourceEffect;
 import org.eclipse.swt.events.ControlAdapter;
 import org.eclipse.swt.events.ControlEvent;
+import org.eclipse.swt.events.DisposeEvent;
+import org.eclipse.swt.events.DisposeListener;
+import org.eclipse.swt.events.FocusAdapter;
+import org.eclipse.swt.events.FocusEvent;
+import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.KeyAdapter;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.MouseAdapter;
@@ -73,20 +82,26 @@ import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
+import org.eclipse.swt.graphics.Cursor;
+import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.Scale;
 import org.eclipse.swt.widgets.Slider;
+import org.eclipse.swt.widgets.Text;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeColumn;
 import org.eclipse.swt.widgets.TreeItem;
@@ -106,6 +121,7 @@ import org.slf4j.LoggerFactory;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.app.ColorUtil;
 import ch.kuramo.javie.app.CommandIds;
+import ch.kuramo.javie.app.ImageUtil;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.app.IntervalTask;
 import ch.kuramo.javie.app.PropertyUtil;
@@ -116,6 +132,7 @@ import ch.kuramo.javie.app.actions.AddExpressionsAction;
 import ch.kuramo.javie.app.actions.KeyframeInterpolationAction;
 import ch.kuramo.javie.app.actions.QTMovieOutputAction;
 import ch.kuramo.javie.app.actions.RemoveKeyframesAction;
+import ch.kuramo.javie.app.actions.RenameLayerOrEffectAction;
 import ch.kuramo.javie.app.actions.ResetAnimatableValuesAction;
 import ch.kuramo.javie.app.actions.ReverseLayerTimeAction;
 import ch.kuramo.javie.app.actions.SequenceOutputAction;
@@ -144,8 +161,13 @@ import ch.kuramo.javie.app.views.layercomp.EffectElement;
 import ch.kuramo.javie.app.views.layercomp.EffectsElement;
 import ch.kuramo.javie.app.views.layercomp.Element;
 import ch.kuramo.javie.app.views.layercomp.LayerAnimatableValueElement;
+import ch.kuramo.javie.app.views.layercomp.LayerCompFrameBlendAction;
+import ch.kuramo.javie.app.views.layercomp.LayerCompMotionBlurAction;
+import ch.kuramo.javie.app.views.layercomp.LayerCompSettingsAction;
+import ch.kuramo.javie.app.views.layercomp.LayerCompShyAction;
 import ch.kuramo.javie.app.views.layercomp.LayerElement;
 import ch.kuramo.javie.app.views.layercomp.TimelineManager;
+import ch.kuramo.javie.app.widgets.FontUtil;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.Effect;
@@ -155,16 +177,20 @@ import ch.kuramo.javie.core.Folder;
 import ch.kuramo.javie.core.Interpolation;
 import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.ItemLayer;
+import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Keyframe;
 import ch.kuramo.javie.core.Layer;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.MediaItem;
+import ch.kuramo.javie.core.TimeCode;
 import ch.kuramo.javie.core.TransformableLayer;
 import ch.kuramo.javie.core.Util;
 import ch.kuramo.javie.core.services.AnimatableValueCollector;
 import ch.kuramo.javie.core.services.EffectRegistry;
 
 import com.google.inject.Inject;
+import com.ibm.icu.text.Normalizer;
+import com.ibm.icu.text.Transliterator;
 
 public class LayerCompositionView extends ViewPart
 		implements ProjectListener, PlayerLinkListener {
@@ -184,6 +210,8 @@ public class LayerCompositionView extends ViewPart
 	public static final String LAYER_COMPOSITION = "LAYER_COMPOSITION";
 	public static final String ANIMATABLE_VALUES = "ANIMATABLE_VALUES";
 	public static final String TIMELINE_MANAGER = "TIMELINE_MANAGER";
+	public static final String LAYER_NAME_MODE = "LAYER_NAME_MODE";
+	public static final String EDIT_ELEMENT_NAME = "EDIT_ELEMENT_NAME";
 
 
 	private static final Logger _logger = LoggerFactory.getLogger(LayerCompositionView.class);
@@ -195,9 +223,15 @@ public class LayerCompositionView extends ViewPart
 	private static final int ROW_PADDING = 4;
 
 
-	private Composite _topLeftSpacer;
+	private Text _searchText;
 
-	private Composite _bottomLeftSpacer;
+	private Composite _timeCodeComposite;
+
+	private Label _fpsLabel;
+
+	private Composite _topSpacer;
+
+	private Composite _bottomSpacer;
 
 	private Composite _timelineMeter;
 
@@ -207,6 +241,8 @@ public class LayerCompositionView extends ViewPart
 
 	private TreeViewer _treeViewer;
 
+	private TreeViewerColumn _nameColumn;
+
 	private Action _newCameraLayerAction;
 
 	private Action _newNullLayerAction;
@@ -269,11 +305,13 @@ public class LayerCompositionView extends ViewPart
 
 		parent.setLayout(new FormLayout());
 
-		_topLeftSpacer = new Composite(parent, SWT.NONE);
-		_bottomLeftSpacer = new Composite(parent, SWT.NONE);
+		_topSpacer = new Composite(parent, SWT.NONE);
+		_bottomSpacer = new Composite(parent, SWT.NONE);
 
 		createTreeViewer(parent);
 		createTimelineControls(parent);
+		createSearchText(parent);
+		createTimeCodeControls(parent);
 		setLayoutData();
 
 		setupGlobalActionsAndContextMenu();
@@ -281,8 +319,13 @@ public class LayerCompositionView extends ViewPart
 
 		_timelineUpdateTask = new IntervalTask(parent.getDisplay(), 50) {
 			public void run() {
-				if (!parent.isDisposed() && _timelineManager != null) {
-					_timelineManager.update(_time, true);
+				if (!parent.isDisposed()) {
+					if (_timelineManager != null) {
+						_timelineManager.update(_time, true);
+					}
+					if (_timeCodeComposite != null) {
+						_timeCodeComposite.redraw();
+					}
 				}
 			}
 		};
@@ -296,6 +339,7 @@ public class LayerCompositionView extends ViewPart
 		};
 
 		setProjectManager(pm);
+		setupActionBars();
 
 		ProjectEventHub.getHub().addProjectListener(this);
 	}
@@ -332,7 +376,10 @@ public class LayerCompositionView extends ViewPart
 		_treeViewer.setData(LAYER_COMPOSITION, _composition);
 		_treeViewer.setInput(_composition);
 
-		_time = Time.fromFrameNumber(0, _composition.getFrameDuration());
+		Time frameDuration = _composition.getFrameDuration();
+		_fpsLabel.setText(String.format("(%.2f fps)", (double)frameDuration.timeScale / frameDuration.timeValue));
+
+		_time = Time.fromFrameNumber(0, frameDuration);
 		_timelineManager = new TimelineManager(
 				pm, _composition, this, _timelineMeter, _timelineScale, _timelineSlider, _treeViewer.getTree());
 		_treeViewer.setData(TIMELINE_MANAGER, _timelineManager);
@@ -362,6 +409,14 @@ public class LayerCompositionView extends ViewPart
 				handleItemNameChange(event);
 				break;
 
+			case COMPOSITION_SETTINGS_CHANGE:
+				handleCompositionSettingsChange(event);
+				break;
+
+			case COMPOSITION_PROPERTY_CHANGE:
+				handleCompositionPropertyChange(event);
+				break;
+
 			case LAYER_PROPERTY_CHANGE:
 				handleLayerPropertyChange(event);
 				break;
@@ -413,6 +468,8 @@ public class LayerCompositionView extends ViewPart
 		_timelineScale = new Scale(parent, SWT.HORIZONTAL);
 		_timelineSlider = new Slider(parent, SWT.HORIZONTAL);
 
+		FontUtil.setCompatibleFont(_timelineMeter);
+
 		SelectionListener selectionListener = new SelectionAdapter() {
 			public void widgetSelected(SelectionEvent e) {
 				_timelineManager.update(_time, false);
@@ -449,17 +506,21 @@ public class LayerCompositionView extends ViewPart
 		tree.setHeaderVisible(true);
 		tree.setLinesVisible(!COCOA);
 
+		FontUtil.setCompatibleFont(tree);
+
 		final DragSourceEffect dragEffect = new DragSourceEffect(tree);
 		tree.setData("DEFAULT_DRAG_SOURCE_EFFECT", dragEffect);
 
-		createViewerColumn(NAME_COL,      200, null, "ソース名");
-		createViewerColumn(VALUE_COL,     150, null, "");
-		createViewerColumn(MODE_COL,       50, null, "モード");
-		createViewerColumn(TRACKMATTE_COL, 50, null, "ﾄﾗｯｸﾏｯﾄ");
-		createViewerColumn(PARENT_COL,    100, null, "親");
-		createViewerColumn(SHOWHIDE_COL,   60, null, "");
-		createViewerColumn(LABEL_COL,      40, null, "");
-		createViewerColumn(TIMELINE_COL,  300, null, "");
+		_nameColumn =	createViewerColumn(NAME_COL,      200, null, "ソース名");
+						createViewerColumn(VALUE_COL,     150, ImageUtil.getSwitchesHeaderIcon(), "");
+						createViewerColumn(MODE_COL,       50, null, "モード");
+						createViewerColumn(TRACKMATTE_COL, 50, null, "ﾄﾗｯｸﾏｯﾄ");
+						createViewerColumn(PARENT_COL,    100, null, "親");
+						createViewerColumn(SHOWHIDE_COL,   60, ImageUtil.getShowhideHeaderIcon(), "");
+						createViewerColumn(LABEL_COL,      40, null, "");
+						createViewerColumn(TIMELINE_COL,  300, null, "");
+
+		setLayerNameMode(false);
 
 
 		ControlAdapter columnWidthAdjuster = new ControlAdapter() {
@@ -591,7 +652,7 @@ public class LayerCompositionView extends ViewPart
 		});
 	}
 
-	private TreeViewerColumn createViewerColumn(int columnIndex, int width, Image image, String name) {
+	private TreeViewerColumn createViewerColumn(final int columnIndex, int width, Image image, String name) {
 		TreeViewerColumn viewerColumn = new TreeViewerColumn(_treeViewer, SWT.NONE);
 		TreeColumn column = viewerColumn.getColumn();
 		column.setWidth(width);
@@ -599,6 +660,12 @@ public class LayerCompositionView extends ViewPart
 		column.setText(name);
 		column.setMoveable(false);
 
+		column.addSelectionListener(new SelectionAdapter() {
+			public void widgetSelected(SelectionEvent e) {
+				treeColumnSelected(columnIndex);
+			}
+		});
+
 		viewerColumn.setLabelProvider(new TreeColumnViewerLabelProvider(new LayerCompositionLabelProvider()));
 		viewerColumn.setEditingSupport(createEditingSupport(columnIndex));
 
@@ -628,6 +695,276 @@ public class LayerCompositionView extends ViewPart
 		};
 	}
 
+	private void createSearchText(Composite parent) {
+		final TreePath[][] treePaths = new TreePath[1][];
+
+		final Color colorGray = parent.getDisplay().getSystemColor(SWT.COLOR_GRAY);
+		final Color colorBlack = parent.getDisplay().getSystemColor(SWT.COLOR_BLACK);
+
+		_searchText = new Text(parent, SWT.SEARCH | SWT.ICON_SEARCH);
+		_searchText.setForeground(colorGray);
+		_searchText.setText("検索");
+
+		FontUtil.setCompatibleFont(_searchText);
+
+		_searchText.addKeyListener(new KeyAdapter() {
+			public void keyPressed(KeyEvent e) {
+				switch (e.character) {
+					case SWT.CR:
+						searchTreeItem();
+						break;
+					case SWT.ESC:
+						if (treePaths[0] != null) {
+							_treeViewer.setExpandedTreePaths(treePaths[0]);
+						}
+						_searchText.setText("");
+						break;
+				}
+			}
+		});
+
+		_searchText.addFocusListener(new FocusListener() {
+			private String savedText = "";
+
+			public void focusGained(FocusEvent e) {
+				treePaths[0] = _treeViewer.getExpandedTreePaths();
+				_searchText.setText(savedText);
+				_searchText.setForeground(colorBlack);
+			}
+
+			public void focusLost(FocusEvent e) {
+				treePaths[0] = null;
+				savedText = _searchText.getText();
+				_searchText.setForeground(colorGray);
+				_searchText.setText("検索");
+			}
+		});
+	}
+
+	private void createTimeCodeControls(Composite parent) {
+		Display display = parent.getDisplay();
+
+		_timeCodeComposite = new Composite(parent, WIN32 ? SWT.DOUBLE_BUFFERED : SWT.NONE);
+		_fpsLabel = new Label(parent, SWT.NONE);
+
+		FontUtil.setCompatibleFont(_timeCodeComposite);
+		FontUtil.setCompatibleFont(_fpsLabel);
+
+		final Font font = new Font(display,
+				_timeCodeComposite.getFont().getFontData()[0].getName(), COCOA ? 16 : 14, SWT.BOLD);
+
+		_timeCodeComposite.addDisposeListener(new DisposeListener() {
+			public void widgetDisposed(DisposeEvent e) {
+				font.dispose();
+			}
+		});
+
+		_timeCodeComposite.setFont(font);
+		_timeCodeComposite.setForeground(display.getSystemColor(SWT.COLOR_DARK_BLUE));
+		_timeCodeComposite.setLayout(new FillLayout());
+
+		final Text editor = new Text(_timeCodeComposite, SWT.RIGHT);
+		editor.setVisible(false);
+		editor.setFont(font);
+		editor.setBackground(_timeCodeComposite.getBackground());
+
+		final boolean[] editorCanceled = new boolean[1];
+
+		editor.addFocusListener(new FocusAdapter() {
+			public void focusLost(FocusEvent e) {
+				editor.setVisible(false);
+				if (!editorCanceled[0]) {
+					Time frameDuration = _composition.getFrameDuration();
+					Time time = Time.fromFrameNumber(TimeCode.parseTimeCode(editor.getText(), frameDuration), frameDuration);
+					if (time.timeValue < 0) {
+						time = new Time(0, time.timeScale);
+					} else if (!time.before(_composition.getDuration())) {
+						time = _composition.getDuration().subtract(frameDuration);
+					}
+					time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
+					update(time);
+				}
+			}
+		});
+
+		editor.addKeyListener(new KeyAdapter() {
+			public void keyPressed(KeyEvent e) {
+				switch (e.character) {
+					case SWT.ESC:
+						editorCanceled[0] = true;
+						// fall through
+					case SWT.CR:
+						// ここで直接 editor.setVisible(false) をすると、ESCを押したときになぜか警告音が鳴る。
+						e.display.asyncExec(new Runnable() {
+							public void run() {
+								editor.setVisible(false);
+							}
+						});
+						break;
+				}
+			}
+		});
+
+
+		final Rectangle timeCodeArea = new Rectangle(0, 0, 0, 0);
+
+		_timeCodeComposite.addPaintListener(new PaintListener() {
+			private final int[] underlineDash = new int[] { 2, 2 };
+
+			public void paintControl(PaintEvent e) {
+				if (_time == null || _composition == null) {
+					return;
+				}
+
+				GC gc = e.gc;
+
+				String timeCode = TimeCode.toTimeCode(_time, _composition.getFrameDuration());
+				Point extent = gc.textExtent(timeCode, SWT.DRAW_TRANSPARENT);
+				Point size = _timeCodeComposite.getSize();
+				int x = size.x - extent.x + (COCOA ? -3 : WIN32 ? -1 : 0);
+				int y = (size.y - extent.y) / 2;
+				gc.drawString(timeCode, x, y, true);
+
+				timeCodeArea.x = x;
+				timeCodeArea.y = y;
+				timeCodeArea.width = extent.x;
+				timeCodeArea.height = extent.y;
+
+				y += extent.y;
+				gc.setLineDash(underlineDash);
+				if (COCOA) {
+					gc.drawLine(x, y - 1, x + extent.x + 1, y - 1);
+				} else if (WIN32) {
+					gc.drawLine(x, y, x + extent.x - 3, y);
+				} else {
+					gc.drawLine(x, y, x + extent.x, y);
+				}
+			}
+		});
+
+		final Cursor handCursor = display.getSystemCursor(SWT.CURSOR_HAND);
+
+		_timeCodeComposite.addMouseMoveListener(new MouseMoveListener() {
+			public void mouseMove(MouseEvent e) {
+				_timeCodeComposite.setCursor(
+						timeCodeArea.contains(e.x, e.y) ? handCursor : null);
+			}
+		});
+
+		_timeCodeComposite.addMouseListener(new MouseAdapter() {
+			private Listener filter;
+
+			public void mouseDown(MouseEvent event) {
+				if (!timeCodeArea.contains(event.x, event.y) || filter != null) {
+					return;
+				}
+
+				final Display display = event.display;
+				final long downTime = System.currentTimeMillis();
+				final Point downPoint = _timeCodeComposite.toDisplay(event.x, event.y);
+
+				final Time frameDuration = _composition.getFrameDuration();
+				final long originalValue = _time.toFrameNumber(frameDuration);
+
+				filter = new Listener() {
+					private boolean dragDetected;
+					private Point detectPoint;
+					private Point prevPoint;
+					private double[] currentPoint;
+
+					public void handleEvent(Event e) {
+						switch (e.type) {
+							case SWT.MouseMove:
+								if (!_timeCodeComposite.isDisposed()) {
+									if (COCOA && (getCocoaCurrentButtonState() & 1) == 0) {
+										break;
+									}
+
+									Point pt = display.getCursorLocation();
+
+									if (!dragDetected) {
+										dragDetected = (System.currentTimeMillis() - downTime > 100)
+												&& (Math.abs(pt.x - downPoint.x) > 3 || Math.abs(pt.y - downPoint.y) > 3);
+										if (dragDetected) {
+											currentPoint = new double[] { pt.x, pt.y };
+											prevPoint = detectPoint = pt;
+										}
+									}
+
+									if (dragDetected) {
+										double deltaScale = (e.stateMask & SWT.MOD2) != 0 ? 10 :
+															(e.stateMask & SWT.MOD1) != 0 ? 0.1 : 1;
+										currentPoint[0] += (pt.x - prevPoint.x) * deltaScale;
+										currentPoint[1] += (pt.y - prevPoint.y) * deltaScale;
+
+										prevPoint = pt;
+
+										long newValue = (long)(originalValue + currentPoint[0] - detectPoint.x);
+
+										Time time = Time.fromFrameNumber(newValue, frameDuration);
+										if (time.timeValue < 0) {
+											time = new Time(0, time.timeScale);
+										} else if (!time.before(_composition.getDuration())) {
+											time = _composition.getDuration().subtract(frameDuration);
+										}
+										time = Time.fromFrameNumber(time.toFrameNumber(frameDuration), frameDuration);
+
+										update(time);
+									}
+
+									break;
+								}
+								// fall through
+
+							case SWT.MouseUp:
+							case SWT.Deactivate:
+								filter = null;
+
+								display.removeFilter(SWT.MouseMove, this);
+								display.removeFilter(SWT.MouseUp, this);
+								display.removeFilter(SWT.Deactivate, this);
+								_timelineManager.setWrapMode(true);
+
+								if (e.type == SWT.MouseUp && !_timeCodeComposite.isDisposed() && !dragDetected) {
+									editorCanceled[0] = false;
+									editor.setText(TimeCode.toTimeCode(_time, _composition.getFrameDuration()));
+									editor.selectAll();
+									editor.setVisible(true);
+									if (!editor.setFocus()) {
+										editor.setVisible(false);
+									}
+								}
+								break;
+						}
+					}
+				};
+
+				_timelineManager.setWrapMode(false);
+				display.addFilter(SWT.MouseMove, filter);
+				display.addFilter(SWT.MouseUp, filter);
+				display.addFilter(SWT.Deactivate, filter);
+			}
+		});
+	}
+
+	// TODO getCocoaCurrentButtonState は AnimatableValueElementDelegate などにも同じものがある。
+
+	private static Method cocoaGetCurrentButtonStateMethod;
+
+	private static int getCocoaCurrentButtonState() {
+		try {
+			if (cocoaGetCurrentButtonStateMethod == null) {
+				Class<?> clazz = Class.forName("org.eclipse.swt.internal.cocoa.OS");
+				cocoaGetCurrentButtonStateMethod = clazz.getMethod("GetCurrentButtonState");
+			}
+			return (Integer) cocoaGetCurrentButtonStateMethod.invoke(null);
+		} catch (RuntimeException e) {
+			throw e;
+		} catch (Exception e) {
+			throw new JavieRuntimeException(e);
+		}
+	}
+
 	private void setupGlobalActionsAndContextMenu() {
 		// GlobalActions
 
@@ -669,6 +1006,7 @@ public class LayerCompositionView extends ViewPart
 		menuMgr.add(effectMenu);
 		menuMgr.add(animeMenu);
 		menuMgr.add(new Separator());
+		menuMgr.add(new RenameLayerOrEffectAction(this, _treeViewer));
 		menuMgr.add(new ResetAnimatableValuesAction(window, _treeViewer));
 		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
@@ -929,30 +1267,53 @@ public class LayerCompositionView extends ViewPart
 	}
 
 	private void setLayoutData() {
-		FormData data = new FormData();
-		data.left = new FormAttachment(0, 0);
+		FormData data;
+
+		data = new FormData();
+		data.left = new FormAttachment(0, COCOA ? 4 : 6);
+		data.right = new FormAttachment(0, 200);
+		data.top = new FormAttachment(0, COCOA ? 4 : 6);
+		data.bottom = new FormAttachment(0, COCOA ? 26 : 24);
+		_searchText.setLayoutData(data);
+
+		data = new FormData();
+		data.left = new FormAttachment(_searchText, 10, SWT.RIGHT);
+		data.right = new FormAttachment(_searchText, 150, SWT.RIGHT);
+		data.top = new FormAttachment(0, 5);
+		data.bottom = new FormAttachment(0, 25);
+		_timeCodeComposite.setLayoutData(data);
+
+		data = new FormData();
+		data.left = new FormAttachment(_timeCodeComposite, 10, SWT.RIGHT);
+		data.right = new FormAttachment(_timeCodeComposite, 90, SWT.RIGHT);
+		data.top = new FormAttachment(0, COCOA ? 7 : 9);
+		data.bottom = new FormAttachment(0, COCOA ? 23 : 21);
+		_fpsLabel.setLayoutData(data);
+
+		data = new FormData();
+		data.left = new FormAttachment(_fpsLabel, 0, SWT.RIGHT);
 		data.right = new FormAttachment(100, 0);
 		data.top = new FormAttachment(0, 12);
 		data.bottom = new FormAttachment(0, 30);
-		_topLeftSpacer.setLayoutData(data);
+		_topSpacer.setLayoutData(data);
 
 		data = new FormData();
 		data.left = new FormAttachment(0, 0);
 		data.right = new FormAttachment(100, 0);
 		data.top = new FormAttachment(100, COCOA ? -15 : -16);
 		data.bottom = new FormAttachment(100, 0);
-		_bottomLeftSpacer.setLayoutData(data);
+		_bottomSpacer.setLayoutData(data);
 
 		data = new FormData();
-		data.left = new FormAttachment(_topLeftSpacer, 0, SWT.RIGHT);
+		data.left = new FormAttachment(_topSpacer, 0, SWT.RIGHT);
 		data.right = new FormAttachment(100, 0);
 		data.top = new FormAttachment(0, 12);
 		data.bottom = new FormAttachment(0, 30);
 		_timelineMeter.setLayoutData(data);
 
 		data = new FormData();
-		data.left = new FormAttachment(_bottomLeftSpacer, 0, SWT.RIGHT);
-		data.right = new FormAttachment(_bottomLeftSpacer, 150, SWT.RIGHT);
+		data.left = new FormAttachment(_bottomSpacer, 0, SWT.RIGHT);
+		data.right = new FormAttachment(_bottomSpacer, 150, SWT.RIGHT);
 		data.top = new FormAttachment(100, COCOA ? -15 : -27);
 		data.bottom = new FormAttachment(100, 0);
 		_timelineScale.setLayoutData(data);
@@ -967,11 +1328,134 @@ public class LayerCompositionView extends ViewPart
 		data = new FormData();
 		data.left = new FormAttachment(0, 0);
 		data.right = new FormAttachment(100, 0);
-		data.top = new FormAttachment(_topLeftSpacer, 0, SWT.BOTTOM);
+		data.top = new FormAttachment(_topSpacer, 0, SWT.BOTTOM);
 		data.bottom = new FormAttachment(_timelineSlider, 0, SWT.TOP);
 		_treeViewer.getTree().setLayoutData(data);
 	}
 
+	private void treeColumnSelected(int columnIndex) {
+		switch (columnIndex) {
+			case NAME_COL:
+				setLayerNameMode(!isLayerNameMode());
+				break;
+		}
+	}
+
+	private boolean isLayerNameMode() {
+		return Boolean.TRUE.equals(_treeViewer.getData(LAYER_NAME_MODE));
+	}
+
+	private void setLayerNameMode(boolean layerNameMode) {
+		if (isLayerNameMode() != layerNameMode) {
+			_treeViewer.setData(LAYER_NAME_MODE, layerNameMode);
+			_nameColumn.getColumn().setText(layerNameMode ? "レイヤー名" : "ソース名");
+			_treeViewer.refresh();
+		}
+	}
+
+	public void editElementName(Element element) {
+		if (element instanceof LayerElement || element instanceof EffectElement) {
+			if (element instanceof LayerElement) {
+				setLayerNameMode(true);
+			}
+			_treeViewer.setData(EDIT_ELEMENT_NAME, Boolean.TRUE);
+			_treeViewer.editElement(element, NAME_COL);
+			_treeViewer.setData(EDIT_ELEMENT_NAME, null);
+		} else {
+			throw new IllegalArgumentException("element must be LayerElement or EffectElement");
+		}
+	}
+
+	private static final Transliterator H2K_TRANSLITERATOR = Transliterator.getInstance("Hiragana-Katakana");
+
+	private void searchTreeItem() {
+		String query = _searchText.getText();
+		query = Normalizer.normalize(query, Normalizer.NFKC);
+		query = H2K_TRANSLITERATOR.transliterate(query);
+		query = query.trim().toLowerCase();
+
+		Tree tree = _treeViewer.getTree();
+		TreeItem found = null;
+
+		if (query.length() != 0) {
+			TreeItem item = null;
+
+			TreeSelection selection = (TreeSelection) _treeViewer.getSelection();
+			Object element = selection.getFirstElement();
+			if (element != null) {
+				for (TreeItem ti : tree.getSelection()) {
+					if (ti.getData() == element) {
+						item = ti;
+						break;
+					}
+				}
+			}
+
+			if (item != null) {
+				found = searchTreeItem(query, item, false);
+
+				while (found == null && item != null) {
+					TreeItem parentItem = item.getParentItem();
+					List<TreeItem> items = Arrays.asList(
+							parentItem != null ? parentItem.getItems() : tree.getItems());
+
+					int index = items.indexOf(item);
+					for (int i = index + 1; found == null && i < items.size(); ++i) {
+						found = searchTreeItem(query, items.get(i), true);
+					}
+					item = parentItem;
+				}
+			}
+
+			if (found == null) {
+				for (TreeItem ti : tree.getItems()) {
+					found = searchTreeItem(query, ti, true);
+					if (found != null) {
+						break;
+					}
+				}
+			}
+		}
+
+		selectAndReveal(found);
+		if (found == null) {
+			tree.getDisplay().beep();
+		}
+	}
+
+	private TreeItem searchTreeItem(String query, TreeItem fromItem, boolean includeFromItem) {
+		if (includeFromItem) {
+			String text = fromItem.getText();
+			text = Normalizer.normalize(text, Normalizer.NFKC);
+			text = H2K_TRANSLITERATOR.transliterate(text);
+			text = text.trim().toLowerCase();
+			if (text.contains(query)) {
+				return fromItem;
+			}
+		}
+
+		Object element = fromItem.getData();
+		if (_treeViewer.isExpandable(element)) {
+			boolean expanded = _treeViewer.getExpandedState(element);
+			_treeViewer.getTree().setRedraw(false);
+			try {
+				_treeViewer.setExpandedState(element, true);
+
+				for (TreeItem ti: fromItem.getItems()) {
+					ti = searchTreeItem(query, ti, true);
+					if (ti != null) {
+						return ti;
+					}
+				}
+			} finally {
+				_treeViewer.setExpandedState(element, expanded);
+				_treeViewer.getTree().setRedraw(true);
+			}
+		}
+
+		return null;
+	}
+
 	private void adjustColumnWidth() {
 		Tree tree = _treeViewer.getTree();
 
@@ -992,16 +1476,16 @@ public class LayerCompositionView extends ViewPart
 			lastColumn.setWidth(lastColumnWidth);
 		}
 
-		FormData data1 = (FormData) _topLeftSpacer.getLayoutData();
-		FormData data2 = (FormData) _bottomLeftSpacer.getLayoutData();
+		FormData data1 = (FormData) _topSpacer.getLayoutData();
+		FormData data2 = (FormData) _bottomSpacer.getLayoutData();
 		data1.right.numerator = data2.right.numerator = 0;
 		data1.right.offset = data2.right.offset = clientWidth - lastColumnWidth;
 
-		final Composite parent = _bottomLeftSpacer.getParent();
+		final Composite parent = _bottomSpacer.getParent();
 		parent.getDisplay().asyncExec(new Runnable() {
 			public void run() {
 				if (!parent.isDisposed()) {
-					parent.layout(new Control[] { _topLeftSpacer, _bottomLeftSpacer });
+					parent.layout(new Control[] { _topSpacer, _bottomSpacer });
 				}
 			}
 		});
@@ -1024,6 +1508,19 @@ public class LayerCompositionView extends ViewPart
 		_treeViewer.getTree().setCursor(null);
 	}
 
+	private void setupActionBars() {
+		IActionBars actionBars = getViewSite().getActionBars();
+		IToolBarManager tbm = actionBars.getToolBarManager();
+
+		tbm.add(new LayerCompShyAction(this));
+		tbm.add(new LayerCompFrameBlendAction(this));
+		tbm.add(new LayerCompMotionBlurAction(this));
+		tbm.add(new Separator());
+		tbm.add(new LayerCompSettingsAction(this));
+
+		actionBars.updateActionBars();
+	}
+
 	private TreeItem _shiftSelectionBaseItem;
 
 	private void emulateFullSelectionMouseDown(MouseEvent e, TreeItem item, int columnIndex) {
@@ -1212,12 +1709,17 @@ public class LayerCompositionView extends ViewPart
 		return null;
 	}
 
-	private void moveLayers(List<LayerElement> layerElements, LayerElement moveBefore) {
-		List<LayerElement> current = Util.newList();
-		for (TreeItem treeItem : _treeViewer.getTree().getItems()) {
-			current.add((LayerElement) treeItem.getData());
+	private List<LayerElement> getLayerElements() {
+		List<LayerElement> list = Util.newList();
+		LayerCompositionContentProvider cp = (LayerCompositionContentProvider) _treeViewer.getContentProvider();
+		for (Object element : cp.getElements(_composition)) {
+			list.add((LayerElement) element);
 		}
+		return list;
+	}
 
+	private void moveLayers(List<LayerElement> layerElements, LayerElement moveBefore) {
+		List<LayerElement> current = getLayerElements();
 		int moveToIndex = (moveBefore != null) ? current.indexOf(moveBefore) : current.size();
 
 		// サブリストを並行して更新すると ConcurrentModificationException が発生するので複製して使う。
@@ -1249,14 +1751,14 @@ public class LayerCompositionView extends ViewPart
 	}
 
 	private void newLayers(List<Item> items, LayerElement insertBefore) {
-		TreeItem[] treeItems = _treeViewer.getTree().getItems();
+		List<LayerElement> current = getLayerElements();
 		int insertIndex = -1;
 
 		if (insertBefore == null) {
-			insertIndex = treeItems.length;
+			insertIndex = current.size();
 		} else {
-			for (int i = 0; i < treeItems.length; ++i) {
-				if (treeItems[i].getData() == insertBefore) {
+			for (int i = 0; i < current.size(); ++i) {
+				if (current.get(i) == insertBefore) {
 					insertIndex = i;
 					break;
 				}
@@ -1267,7 +1769,7 @@ public class LayerCompositionView extends ViewPart
 		}
 
 		// Treeの表示順は内部データと逆順。
-		insertIndex = treeItems.length - insertIndex;
+		insertIndex = current.size() - insertIndex;
 
 		items = Util.newList(items);
 		Collections.reverse(items);
@@ -1458,14 +1960,61 @@ public class LayerCompositionView extends ViewPart
 		_treeViewer.setSelection(new TreeSelection(list.toArray(new TreePath[list.size()])), true);
 	}
 
+	private void handleCompositionSettingsChange(ProjectEvent event) {
+		if (event.composition != _composition) {
+			return;
+		}
+
+		// 今のところ、ここでやることは無い。
+	}
+
+	private void handleCompositionPropertyChange(ProjectEvent event) {
+		if (event.composition != _composition) {
+			return;
+		}
+
+		if (event.property.equals("shyEnabled")) {
+			if (_composition.isShyEnabled()) {
+				// TODO ここでキーフレームの選択状態を解除するのは暫定的な措置。
+				//      そうしないと handleKeyframesChange と handleLayerSlipEdit が正常に動作しない。
+				//      選択状態を維持したままシャイを有効にできるようにするか、
+				//      シャイで非表示になったレイヤー内のキーフレームだけ選択解除するようにするべき。
+				_timelineManager.clearKeyframeSelection();
+
+				_treeViewer.addFilter(ShyFilter.INSTANCE);
+			} else {
+				_treeViewer.removeFilter(ShyFilter.INSTANCE);
+			}
+		}
+	}
+
 	private void handleLayerPropertyChange(ProjectEvent event) {
 		if (event.composition != _composition) {
 			return;
 		}
 
-		Tree tree = _treeViewer.getTree();
+		if (event.property.equals("shy") && _composition.isShyEnabled()) {
+			_treeViewer.refresh();
+			return;
+		}
 
-		for (TreeItem treeItem : tree.getItems()) {
+		Tree tree = _treeViewer.getTree();
+		TreeItem[] treeItems = tree.getItems();
+
+		if (event.property.equals("name")) {
+			Set<Element> elements = Util.newSet();
+			for (TreeItem treeItem : treeItems) {
+				LayerElement layerElement = (LayerElement) treeItem.getData();
+				if (layerElement.layer.getParent() == event.layer) {
+					elements.add(layerElement);
+				}
+			}
+			if (!elements.isEmpty()) {
+				_treeViewer.update(elements.toArray(), null);
+			}
+		}
+
+		for (TreeItem treeItem : treeItems) {
 			LayerElement layerElement = (LayerElement) treeItem.getData();
 			if (layerElement.layer == event.layer) {
 				if (ProjectEvent.propertyIsAnimatable(event)) {
@@ -1698,21 +2247,20 @@ public class LayerCompositionView extends ViewPart
 
 		EffectableLayer layer = (EffectableLayer) event.layer;
 		Effect effect = layer.getEffects().get(event.effectIndex);
+		String property = event.property;
 
 		for (TreeItem treeItem : _treeViewer.getTree().getItems()) {
 			LayerElement layerElement = (LayerElement) treeItem.getData();
 			if (layerElement.layer == layer) {
 				if (ProjectEvent.propertyIsAnimatable(event)) {
-					treeItem = findEffectAnimatableValueItem(treeItem, effect, event.property);
+					treeItem = findEffectAnimatableValueItem(treeItem, effect, property);
 
-				} else if (event.property.equals("enabled")) {
+				} else if (property.equals("name") || property.equals("enabled")) {
 					treeItem = findEffectItem(treeItem, effect);
-					// findEffectItemの中で Tree#setRedraw(false/true) をしてるので update をする必要はない。 
-					//_treeViewer.update(treeItem.getData(), null);
+					_treeViewer.update(treeItem.getData(), null);
 
 				} else {
-					// TODO AnimatableValue でなく enabled でもないプロパティの場合。
-					//treeItem = findEffectPropertyItem(treeItem, effect, event.property);
+					//treeItem = findEffectPropertyItem(treeItem, effect, property);
 				}
 
 				selectAndReveal(treeItem);
@@ -1960,6 +2508,7 @@ public class LayerCompositionView extends ViewPart
 			_time = time;
 			collectAnimatableValues(time);
 			_timelineManager.update(time, true);
+			_timeCodeComposite.redraw();
 		} else {
 			collectAnimatableValues(time);
 			refreshPlayer(time);
@@ -2058,7 +2607,11 @@ public class LayerCompositionView extends ViewPart
 						return;
 					}
 				}
-				for (IViewPart vp : page.getViewStack(targetView)) {
+				IViewPart[] stack = page.getViewStack(targetView);
+				if (stack == null) {
+					return;
+				}
+				for (IViewPart vp : stack) {
 					if (vp != targetView && page.isPartVisible(vp) &&
 							vp instanceof MediaPlayerView && ((MediaPlayerView) vp).isPinned()) {
 						return;
@@ -2080,3 +2633,22 @@ public class LayerCompositionView extends ViewPart
 	}
 
 }
+
+class ShyFilter extends ViewerFilter {
+
+	static final ShyFilter INSTANCE = new ShyFilter();
+
+
+	private ShyFilter() {
+		super();
+	}
+
+	@Override
+	public boolean select(Viewer viewer, Object parentElement, Object element) {
+		if (element instanceof LayerElement) {
+			return !((LayerElement) element).layer.isShy();
+		}
+		return true;
+	}
+
+}
