@@ -83,6 +83,7 @@ import ch.kuramo.javie.app.project.NewFileItemsOperation;
 import ch.kuramo.javie.app.project.ProjectManager;
 import ch.kuramo.javie.app.project.RenameItemOperation;
 import ch.kuramo.javie.app.project.ReparentItemsOperation;
+import ch.kuramo.javie.app.widgets.FontUtil;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.Folder;
 import ch.kuramo.javie.core.Item;
@@ -117,6 +118,8 @@ public class ProjectView extends ViewPart {
 		tree.setHeaderVisible(true);
 		tree.setLinesVisible(!COCOA);
 
+		FontUtil.setCompatibleFont(tree);
+
 		tree.setBackground(ColorUtil.tableBackground());
 
 		if (COCOA) {
