@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app.views.layercomp;
 
+import java.lang.reflect.Method;
 import java.util.List;
 import java.util.Map;
 
@@ -47,6 +48,7 @@ import ch.kuramo.javie.app.project.ProjectOperation;
 import ch.kuramo.javie.app.views.LayerCompositionView;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.ArithmeticalAnimatableValue;
+import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Util;
 
 public abstract class AnimatableValueElementDelegate<V> {
@@ -384,6 +386,23 @@ public abstract class AnimatableValueElementDelegate<V> {
 	}
 
 
+	private static Method cocoaGetCurrentButtonStateMethod;
+
+	private static int getCocoaCurrentButtonState() {
+		try {
+			if (cocoaGetCurrentButtonStateMethod == null) {
+				Class<?> clazz = Class.forName("org.eclipse.swt.internal.cocoa.OS");
+				cocoaGetCurrentButtonStateMethod = clazz.getMethod("GetCurrentButtonState");
+			}
+			return (Integer) cocoaGetCurrentButtonStateMethod.invoke(null);
+		} catch (RuntimeException e) {
+			throw e;
+		} catch (Exception e) {
+			throw new JavieRuntimeException(e);
+		}
+	}
+
+
 	protected class DragGestureEditor {
 
 		private final String relation = Util.randomId();
@@ -417,6 +436,13 @@ public abstract class AnimatableValueElementDelegate<V> {
 					switch (e.type) {
 						case SWT.MouseMove:
 							if (!control.isDisposed()) {
+								// MacOSXの場合、マウスボタンを離してからも少しの間 MouseMove イベントが発生することがあり、
+								// ユーザーの意図しないところまでドラッグ状態が続いてしまうことがある。
+								// マウスボタンの状態を直接取得するとすでにマウスボタンが離されていることが検出できるので、それで対処している。
+								if (COCOA && (getCocoaCurrentButtonState() & 1) == 0) {
+									break;
+								}
+
 								Point pt = display.getCursorLocation();
 
 								if (!dragDetected) {
