@@ -30,6 +30,7 @@ import java.util.Map;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.CellEditor;
 import org.eclipse.jface.viewers.LabelProvider;
+import org.eclipse.jface.viewers.TextCellEditor;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.MouseEvent;
@@ -37,6 +38,7 @@ import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.widgets.Combo;
+import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.ui.ISharedImages;
 import org.eclipse.ui.PlatformUI;
@@ -46,8 +48,10 @@ import ch.kuramo.javie.app.project.ModifyLayerBlendModeOperation;
 import ch.kuramo.javie.app.project.ModifyLayerParentOperation;
 import ch.kuramo.javie.app.project.ModifyLayerTrackMatteOperation;
 import ch.kuramo.javie.app.project.ProjectManager;
+import ch.kuramo.javie.app.project.RenameLayerOperation;
 import ch.kuramo.javie.app.views.ComboBoxViewerCellEditor;
 import ch.kuramo.javie.app.views.LayerCompositionView;
+import ch.kuramo.javie.app.widgets.WSWin32;
 import ch.kuramo.javie.core.BlendMode;
 import ch.kuramo.javie.core.CameraLayer;
 import ch.kuramo.javie.core.EffectableLayer;
@@ -80,6 +84,8 @@ public class LayerElement extends Element {
 
 	private final SwitchGroup switchesColumnSwitches = new SwitchGroup();
 
+	private TextCellEditor nameEditor;
+
 	private ComboBoxViewerCellEditor modeEditor;
 
 	private ComboBoxViewerCellEditor trackMatteEditor;
@@ -109,14 +115,26 @@ public class LayerElement extends Element {
 
 		switchesColumnSwitches.add(new ShySwitch(pm, layer));
 
+		if (LayerNature.isCTCRNature(layer)) {
+			switchesColumnSwitches.add(new CTCRSwitch(pm, layer));
+		} else {
+			switchesColumnSwitches.addPlaceholder();
+		}
+
 		if (layer instanceof EffectableLayer) {
 			switchesColumnSwitches.add(new EffectsSwitch(pm, (EffectableLayer) layer));
 		} else {
 			switchesColumnSwitches.addPlaceholder();
 		}
 
-		if (LayerNature.isCTCRNature(layer)) {
-			switchesColumnSwitches.add(new CTCRSwitch(pm, layer));
+		if (LayerNature.isFrameBlendNature(layer)) {
+			switchesColumnSwitches.add(new FrameBlendSwitch(pm, layer));
+		} else {
+			switchesColumnSwitches.addPlaceholder();
+		}
+
+		if (LayerNature.isMotionBlurNature(layer)) {
+			switchesColumnSwitches.add(new MotionBlurSwitch(pm, layer));
 		} else {
 			switchesColumnSwitches.addPlaceholder();
 		}
@@ -126,6 +144,12 @@ public class LayerElement extends Element {
 		} else {
 			switchesColumnSwitches.addPlaceholder();
 		}
+
+
+		if (WSWin32.isXPThemed()) {
+			showHideColumnSwitches.setMarginLeft(11);
+			switchesColumnSwitches.setMarginLeft(11);
+		}
 	}
 
 	public Image getColumnImage(int columnIndex) {
@@ -155,13 +179,19 @@ public class LayerElement extends Element {
 	public String getColumnText(int columnIndex) {
 		switch (columnIndex) {
 			case LayerCompositionView.NAME_COL: {
-				String name = layer.getName();
+				String name;
 				if (layer instanceof ItemLayer) {
-					ItemLayer itemLayer = (ItemLayer) layer;
-					String itemName = itemLayer.getItem().getName();
-					if (!name.equals(itemName)) {
-						name = String.format("%s  <%s>", name, itemName);
+					String itemName = ((ItemLayer) layer).getItem().getName();
+					if (isLayerNameMode()) {
+						name = layer.getName();
+						if (name.equals(itemName)) {
+							name = String.format("[%s]", name);
+						}
+					} else {
+						name = itemName;
 					}
+				} else {
+					name = layer.getName();
 				}
 				return name;
 			}
@@ -178,15 +208,28 @@ public class LayerElement extends Element {
 				}
 				return null;
 
-			case LayerCompositionView.PARENT_COL:
+			case LayerCompositionView.PARENT_COL: {
+				String parentName;
 				Layer parent = layer.getParent();
-				return (COCOA ? "  " : "") + ((parent != null) ? parent.getName() : " - ");
+				if (parent == null) {
+					parentName = " - ";
+				} else if (!(parent instanceof ItemLayer) || isLayerNameMode()) {
+					parentName = parent.getName();
+				} else {
+					parentName = ((ItemLayer) parent).getItem().getName();
+				}
+				return (COCOA ? "  " : "") + parentName;
+			}
 
 			default:
 				return null;
 		}
 	}
 
+	private boolean isLayerNameMode() {
+		return Boolean.TRUE.equals(viewer.getData(LayerCompositionView.LAYER_NAME_MODE));
+	}
+
 	private MediaLayer getTrackMatteLayer() {
 		if (layer instanceof MediaLayer) {
 			List<Layer> layers = composition.getLayers();
@@ -331,6 +374,9 @@ public class LayerElement extends Element {
 
 	public boolean canEdit(int columnIndex) {
 		switch (columnIndex) {
+			case LayerCompositionView.NAME_COL:
+				return Boolean.TRUE.equals(viewer.getData(LayerCompositionView.EDIT_ELEMENT_NAME));
+
 			case LayerCompositionView.MODE_COL:
 				return (layer instanceof MediaLayer);
 
@@ -347,6 +393,14 @@ public class LayerElement extends Element {
 
 	public CellEditor getCellEditor(int columnIndex) {
 		switch (columnIndex) {
+			case LayerCompositionView.NAME_COL:
+				if (nameEditor == null) {
+					nameEditor = new TextCellEditor(viewer.getTree(), SWT.SINGLE | SWT.BORDER);
+					Control control = nameEditor.getControl();
+					control.setBackground(control.getDisplay().getSystemColor(SWT.COLOR_WHITE));
+				}
+				return nameEditor;
+
 			case LayerCompositionView.MODE_COL:
 				if (modeEditor == null) {
 					modeEditor = new ComboBoxViewerCellEditor(viewer.getTree(), SWT.READ_ONLY);
@@ -385,7 +439,6 @@ public class LayerElement extends Element {
 				if (parentEditor == null) {
 					parentEditor = new ComboBoxViewerCellEditor(viewer.getTree(), SWT.READ_ONLY);
 					parentEditor.setContenProvider(ArrayContentProvider.getInstance());
-					parentEditor.setLabelProvider(new ParentLabelProvider());
 					parentEditor.setActivationStyle(ComboBoxViewerCellEditor.DROP_DOWN_ON_PROGRAMMATIC_ACTIVATION);
 
 					((Combo) parentEditor.getControl()).addSelectionListener(new SelectionAdapter() {
@@ -394,6 +447,8 @@ public class LayerElement extends Element {
 						}
 					});
 				}
+				parentEditor.setInput(null);
+				parentEditor.setLabelProvider(new ParentLabelProvider(isLayerNameMode()));
 				parentEditor.setInput(getLayersForParentEditor());
 				return parentEditor;
 
@@ -404,6 +459,9 @@ public class LayerElement extends Element {
 
 	public Object getCellEditorValue(int columnIndex) {
 		switch (columnIndex) {
+			case LayerCompositionView.NAME_COL:
+				return layer.getName();
+
 			case LayerCompositionView.MODE_COL:
 				return ((MediaLayer) layer).getBlendMode();
 
@@ -423,6 +481,22 @@ public class LayerElement extends Element {
 		ProjectManager pm = (ProjectManager) viewer.getData(LayerCompositionView.PROJECT_MANAGER);
 
 		switch (columnIndex) {
+			case LayerCompositionView.NAME_COL: {
+				String newName = (String) value;
+				if (newName.length() == 0) {
+					if (layer instanceof ItemLayer) {
+						newName = ((ItemLayer) layer).getItem().getName();
+					} else {
+						// TODO ItemLayer以外の場合、どうするのがいいか？　以下は暫定
+						if (layer instanceof TextLayer) newName = "テキスト";
+						else if (layer instanceof NullLayer) newName = "ヌル";
+						else if (layer instanceof CameraLayer) newName = "カメラ";
+					}
+				}
+				pm.postOperation(new RenameLayerOperation(pm, layer, newName));
+				break;
+			}
+
 			case LayerCompositionView.MODE_COL:
 				pm.postOperation(new ModifyLayerBlendModeOperation(pm, (MediaLayer) layer, (BlendMode) value));
 				break;
@@ -474,8 +548,21 @@ public class LayerElement extends Element {
 	private static final Object NO_PARENT = new Object();
 
 	private static class ParentLabelProvider extends LabelProvider {
+
+		private final boolean layerNameMode;
+
+		private ParentLabelProvider(boolean layerNameMode) {
+			this.layerNameMode = layerNameMode;
+		}
+
 		public String getText(Object element) {
-			return (element != NO_PARENT) ? ((Layer) element).getName() : "なし";
+			if (element == NO_PARENT) {
+				return "なし";
+			} else if (!(element instanceof ItemLayer) || layerNameMode) {
+				return ((Layer) element).getName();
+			} else {
+				return ((ItemLayer) element).getItem().getName();
+			}
 		}
 	}
 
