@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app.views.layercomp;
 
+import java.lang.reflect.Method;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
@@ -85,6 +86,8 @@ import com.google.inject.Inject;
 
 public class TimelineManager {
 
+	private static final boolean COCOA = SWT.getPlatform().equals("cocoa");
+
 	private static final int FRAME_WIDTH = 50;
 	private static final int LEFT_MARGIN = 20;
 	private static final int RIGHT_MARGIN = 40;
@@ -350,6 +353,10 @@ public class TimelineManager {
 				switch (e.type) {
 					case SWT.MouseMove:
 						if (!control.isDisposed()) {
+							if (COCOA && (getCocoaCurrentButtonState() & 1) == 0) {
+								break;
+							}
+
 							x = control.toControl(display.getCursorLocation()).x;
 							updateView(x);
 							break;
@@ -718,6 +725,25 @@ public class TimelineManager {
 	}
 
 
+	// TODO getCocoaCurrentButtonState は AnimatableValueElementDelegate にも同じものがある。
+
+	private static Method cocoaGetCurrentButtonStateMethod;
+
+	private static int getCocoaCurrentButtonState() {
+		try {
+			if (cocoaGetCurrentButtonStateMethod == null) {
+				Class<?> clazz = Class.forName("org.eclipse.swt.internal.cocoa.OS");
+				cocoaGetCurrentButtonStateMethod = clazz.getMethod("GetCurrentButtonState");
+			}
+			return (Integer) cocoaGetCurrentButtonStateMethod.invoke(null);
+		} catch (RuntimeException e) {
+			throw e;
+		} catch (Exception e) {
+			throw new JavieRuntimeException(e);
+		}
+	}
+
+
 	// TODO AnimatableValueElementDelegate.DragGestureEditor と基本的には同じ。できればうまく纏めたい。
 	private abstract class AbstractDragGestureEditor {
 
@@ -753,6 +779,10 @@ public class TimelineManager {
 					switch (e.type) {
 						case SWT.MouseMove:
 							if (!control.isDisposed()) {
+								if (COCOA && (getCocoaCurrentButtonState() & 1) == 0) {
+									break;
+								}
+
 								int x = control.toControl(display.getCursorLocation()).x;
 
 								if (!dragDetected) {
