@@ -39,7 +39,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 
 	private AnimatableVec3d _scale = new AnimatableVec3d(new Vec3d(100, 100, 100));
 
-	private AnimatableVec3d _orientation = new AnimatableVec3d(new Vec3d(0, 0, 0));
+	private AnimatableVec3d _orientation = new AnimatableVec3d(new Vec3d(0, 0, 0), true);
 
 	private AnimatableDouble _rotationX = new AnimatableDouble(0d);
 
@@ -63,6 +63,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setAnchorPoint(AnimatableVec3d anchorPoint) {
+		anchorPoint.copyConfigurationFrom(_anchorPoint);
 		_anchorPoint = anchorPoint;
 	}
 
@@ -71,6 +72,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setPosition(AnimatableVec3d position) {
+		position.copyConfigurationFrom(_position);
 		_position = position;
 	}
 
@@ -79,6 +81,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setScale(AnimatableVec3d scale) {
+		scale.copyConfigurationFrom(_scale);
 		_scale = scale;
 	}
 
@@ -87,6 +90,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setOrientation(AnimatableVec3d orientation) {
+		orientation.copyConfigurationFrom(_orientation);
 		_orientation = orientation;
 	}
 
@@ -95,6 +99,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setRotationX(AnimatableDouble rotationX) {
+		rotationX.copyConfigurationFrom(_rotationX);
 		_rotationX = rotationX;
 	}
 
@@ -103,6 +108,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setRotationY(AnimatableDouble rotationY) {
+		rotationY.copyConfigurationFrom(_rotationY);
 		_rotationY = rotationY;
 	}
 
@@ -111,6 +117,7 @@ public abstract class AbstractTransformableLayer extends AbstractLayer implement
 	}
 
 	public void setRotationZ(AnimatableDouble rotationZ) {
+		rotationZ.copyConfigurationFrom(_rotationZ);
 		_rotationZ = rotationZ;
 	}
 
