@@ -87,7 +87,7 @@ public class AnimatableVec3d extends ArithmeticalAnimatableValue<Vec3d> implemen
 			Time time, Keyframe<Vec3d> k1, Keyframe<Vec3d> k2, Iterator<Entry<Time, Keyframe<Vec3d>>> tail) {
 
 		if (!_slerp) {
-			super.interpolate(time, k1, k2, tail);
+			return super.interpolate(time, k1, k2, tail);
 		}
 
 		switch (k1.interpolation) {
