@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,12 +23,16 @@
 
 package ch.kuramo.javie.core;
 
+import ch.kuramo.javie.api.Time;
+
 public interface CollapseTransformation {
 
 	CollapseTransformation getParent();
 
 	MediaItemLayer getLayer();
 
+	Time getTime();
+
 	double getOpacity();
 
 }
