@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,7 +27,7 @@ public interface ExpressionScope extends Cloneable {
 
 	ExpressionScope clone();
 
-	ExpressionScope createPrecompositionScope();
+	ExpressionScope createPrecompositionScope(Composition preComp);
 
 	void setThis(Expressionee exprnee);
 
