@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,11 +23,31 @@
 
 package ch.kuramo.javie.core;
 
+import java.util.Locale;
+import java.util.MissingResourceException;
+import java.util.ResourceBundle;
+
 public enum Interpolation {
 
 	HOLD,
 	LINEAR,
-	CATMULL_ROM,
-	SLERP
+	CATMULL_ROM;
+
+
+	private final String label = getLabel();
+
+	private String getLabel() {
+		try {
+			String bundleName = Interpolation.class.getPackage().getName() + ".messages";
+			ResourceBundle bundle = ResourceBundle.getBundle(bundleName, Locale.getDefault());
+			return bundle.getString(String.format("%s.%s", Interpolation.class.getSimpleName(), name()));
+		} catch (MissingResourceException e) {
+			return name();
+		}
+	}
+
+	public String label() {
+		return label;
+	}
 
 }
