@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,12 +27,37 @@ import java.util.List;
 
 public interface LayerComposition extends Composition {
 
+	boolean isShyEnabled();
+
+	void setShyEnabled(boolean enabled);
+
+	boolean isFrameBlendEnabled();
+
+	void setFrameBlendEnabled(boolean enabled);
+
+	boolean isMotionBlurEnabled();
+
+	void setMotionBlurEnabled(boolean enabled);
+
+	double getMotionBlurShutterAngle();
+
+	void setMotionBlurShutterAngle(double shutterAngle);
+
+	double getMotionBlurShutterPhase();
+
+	void setMotionBlurShutterPhase(double shutterPhase);
+
+	int getMotionBlurSamples();
+
+	void setMotionBlurSamples(int samples);
+
+
 	List<Layer> getLayers();
 
 	Layer getLayer(String id);
 
 
 	void setupCollapseTransformation(
-			VideoLayerComposer composer, Camera camera, CollapseTransformation ct);
+			VideoLayerComposer composer, Camera camera, CollapseTransformation ct, MotionBlur motionBlur);
 
 }
