@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -31,6 +31,10 @@ public interface MediaItemLayer extends MediaLayer, ItemLayer {
 
 	void setCTCR(boolean ctcr);
 
+	FrameBlend getFrameBlend();
+
+	void setFrameBlend(FrameBlend frameBlend);
+
 	boolean isPrecompositionLayer();
 
 }
