@@ -39,6 +39,10 @@ public interface MediaLayer extends TransformableLayer, EffectableLayer {
 	void setAudioEnabled(boolean enabled);
 
 
+	boolean isMotionBlurEnabled();
+
+	void setMotionBlurEnabled(boolean enabled);
+
 	TrackMatte getTrackMatte();
 
 	void setTrackMatte(TrackMatte trackMatte);
@@ -65,7 +69,8 @@ public interface MediaLayer extends TransformableLayer, EffectableLayer {
 
 
 	void setupVideoRenderer(
-			VideoLayerComposer composer, Camera camera, CollapseTransformation ct);
+			VideoLayerComposer composer, Camera camera, CollapseTransformation ct,
+			MotionBlur motionBlur, boolean frameBlendEnabled);
 
 	AudioBuffer renderAudioChunk();
 
