@@ -144,6 +144,10 @@ public class TimeCode {
 		long fph = fp10m * 6;
 
 		List<String> numbers = Arrays.asList(NON_NUMBER.split(timeCode));
+		if (numbers.isEmpty()) {
+			return 0;
+		}
+
 		Collections.reverse(numbers);
 
 		long frames = 0;
