@@ -23,10 +23,10 @@
 
 package ch.kuramo.javie.core;
 
+import ch.kuramo.javie.api.Time;
+
 public interface VectorMediaInput extends MediaInput {
 
-	void rasterize(
-			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
-			double[] mvMatrix, double[] prjMatrix);
+	void rasterize(VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime);
 
 }
