@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,13 +23,13 @@
 
 package ch.kuramo.javie.core;
 
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
 
 public interface VideoEffect extends Effect {
 
 	VideoBounds getVideoBounds();
 
-	PIVideoBuffer doVideoEffect();
+	IVideoBuffer doVideoEffect();
 
 }
