@@ -27,6 +27,7 @@ import java.util.Collections;
 import java.util.List;
 
 import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.Size2i;
@@ -46,10 +47,12 @@ import ch.kuramo.javie.core.CollapseTransformation;
 import ch.kuramo.javie.core.DepthBuffer;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.ExpressionScope;
+import ch.kuramo.javie.core.FrameBlend;
 import ch.kuramo.javie.core.LayerComposition;
 import ch.kuramo.javie.core.LayerNature;
 import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaLayer;
+import ch.kuramo.javie.core.MotionBlur;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
 import ch.kuramo.javie.core.RenderContext;
@@ -64,6 +67,7 @@ import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.services.AudioEffectPipeline;
 import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.VideoEffectPipeline;
 import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
@@ -84,6 +88,8 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private List<Effect> _effects = Util.newList();
 
+	private boolean _motionBlurEnabled = false;
+
 	private TrackMatte _trackMatte = TrackMatte.NONE;
 
 	private AnimatableVec2d _depthBase = new AnimatableVec2d(new Vec2d(0, 0));
@@ -107,6 +113,9 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	@Inject
 	private VideoEffectPipeline _vePipeline;
 
+	@Inject
+	private GLGlobal _glGlobal;
+
 	@Inject
 	private AudioRenderContext _arContext;
 
@@ -191,6 +200,14 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_effects = effects;
 	}
 
+	public boolean isMotionBlurEnabled() {
+		return _motionBlurEnabled;
+	}
+
+	public void setMotionBlurEnabled(boolean motionBlurEnabled) {
+		_motionBlurEnabled = motionBlurEnabled;
+	}
+
 	public TrackMatte getTrackMatte() {
 		return _trackMatte;
 	}
@@ -272,7 +289,8 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setupVideoRenderer(
-			VideoLayerComposer composer, Camera camera, CollapseTransformation ct) {
+			VideoLayerComposer composer, Camera camera, CollapseTransformation ct,
+			MotionBlur motinBlur, boolean frameBlendEnabled) {
 
 		// トラックマット適用時にこのチェックがあるとまずいので。同じチェックはコンポ側でもしている。
 		//if (!LayerNature.isVideoEnabled(this)) {
@@ -284,14 +302,14 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			return;
 		}
 
-		if (isVectorLayer() && LayerNature.isCTCR(AbstractMediaLayer.this)) {
-			setupVideoRendererCR(composer, camera, ct);
+		if (isVectorLayer() && LayerNature.isCTCR(this)) {
+			setupVideoRendererCR(composer, camera, ct, motinBlur);
 		} else {
-			setupVideoRendererNormal(composer, camera, ct);
+			setupVideoRendererNormal(composer, camera, ct, motinBlur, frameBlendEnabled);
 		}
 	}
 
-	private Time calcVideoMediaTime(MediaInput input) {
+	protected Time calcVideoMediaTime(MediaInput input) {
 		Time time;
 
 		if (LayerNature.isTimeRemapEnabled(this)) {
@@ -300,36 +318,41 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			Time ctxTime = _vrContext.getTime();
 			double t1 = _timeRemap.valueAtTime(new Time(ctxTime.timeValue + 1, ctxTime.timeScale), _vrContext);
 
-			Time frameDuration = input.getVideoFrameDuration();
-			int timeScale = frameDuration.timeScale;
+			Time mediaFrameDuration = input.getVideoFrameDuration();
+			int mediaTimeScale = mediaFrameDuration.timeScale;
 
-			time = new Time(Math.round(t0 * timeScale), timeScale);
+			time = new Time(Math.round(t0 * mediaTimeScale), mediaTimeScale);
 
 			// 変化量が負の時のときは１フレーム分ずらす。
 			if (t0 > t1) {
-				time = time.subtract(frameDuration);
+				time = time.subtract(mediaFrameDuration);
 			}
 
 		} else {
 			time = _vrContext.getTime().subtract(getStartTime());
 
 			double rate = getRate();
-			if (rate != 1.0) {
+			Time mediaFrameDuration = input.getVideoFrameDuration();
+
+			if (mediaFrameDuration != null) {
+				// メディアのタイムスケールにしておかないと他の箇所の計算で誤差が発生することがある。
+				int mediaTimeScale = mediaFrameDuration.timeScale;
+				time = new Time(Math.round(time.toSecond() * rate * mediaTimeScale), mediaTimeScale);
+			} else {
 				time = new Time(Math.round(time.timeValue * rate), time.timeScale);
+			}
 
-				if (rate < 0.0) {
-					Time duration = input.getDuration();
-					if (duration != null) {
-						time = time.add(duration);
+			if (rate < 0.0) {
+				Time mediaDuration = input.getDuration();
+				if (mediaDuration != null) {
+					time = time.add(mediaDuration);
 
-						// 逆再生時は１フレーム分ずらす。
-						Time frameDuration = input.getVideoFrameDuration();
-						time = time.subtract(frameDuration);
+					// 逆再生時は１フレーム分ずらす。
+					time = time.subtract(mediaFrameDuration);
 
-					} else {
-						duration = getOutPoint().subtract(getStartTime());
-						time = time.add(duration);
-					}
+				} else {
+					mediaDuration = getOutPoint().subtract(getStartTime());
+					time = time.add(mediaDuration);
 				}
 			}
 		}
@@ -338,7 +361,8 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	private void setupVideoRendererNormal(
-			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct) {
+			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct,
+			final MotionBlur motionBlur, final boolean frameBlendEnabled) {
 
 		final MediaInput input = getMediaInput();
 		final RenderResolution resolution = _vrContext.getRenderResolution();
@@ -351,25 +375,39 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 		VideoBounds bounds = _vePipeline.getVideoBounds(
 				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBoundsOperation);
-		Vec2d offset = new Vec2d(-bounds.x/resolution.scale, -bounds.y/resolution.scale);
+		final Vec2d offset = new Vec2d(-bounds.x/resolution.scale, -bounds.y/resolution.scale);
 
 		final double[] mvMatrix = new double[16];
 		final double[] prjMatrix = new double[16];
 		createMatrix(camera, ct, offset, mvMatrix, prjMatrix);
 
-		final double opacity;
-		if (ct == null) {
-			opacity = _opacity.value(_vrContext) / 100d;
-		} else {
-			opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
-		}
+
+		final Time time = _vrContext.getTime();
 
 		VideoLayerRenderer r = new VideoLayerRenderer() {
 			public VideoLayerBuffer render(boolean withDepthBuffer) {
+				// コラップスしているときはここで時刻を再度設定する必要がある。
+				_vrContext.setTime(time);
+
+				final double opacity;
+				if (ct == null) {
+					opacity = _opacity.value(_vrContext) / 100d;
+				} else {
+					opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
+				}
+
 				VideoBuffer effectedBuffer = null;
+				VideoBuffer trnsfrmdBuffer = null;
+				DepthBuffer depthBuffer = null;
 				try {
 					WrappedOperation<VideoBuffer> inputBufferOperation = new WrappedOperation<VideoBuffer>() {
 						public VideoBuffer execute() {
+							if (frameBlendEnabled) {
+								FrameBlend frameBlend = LayerNature.getFrameBlend(AbstractMediaLayer.this);
+								if (frameBlend != FrameBlend.NONE) {
+									return blendFrames(frameBlend);
+								}
+							}
 							return input.getVideoFrameImage(calcVideoMediaTime(input));
 						}
 					};
@@ -377,22 +415,42 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 					effectedBuffer = _vePipeline.doVideoEffects(
 							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBufferOperation);
 
-					VideoBuffer trnsfrmdBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
-					trnsfrmdBuffer.allocateAsTexture();
-					trnsfrmdBuffer.clear();
+					if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
+						if (withDepthBuffer) {
+							depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
+							_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
+						}
 
-					DepthBuffer depthBuffer = withDepthBuffer ? _vrSupport.createDepthBuffer(camera.getViewportSize()) : null;
+						final VideoBuffer mblurSrcBuf = effectedBuffer;
+						MotionBlurSampler sampler = new MotionBlurSampler() {
+							public void sample(double[] mvMatrix, double[] prjMatrix, VideoBuffer buffer) {
+								_vrSupport.transform(mblurSrcBuf, buffer, null, mvMatrix, prjMatrix);
+							}
+						};
+						trnsfrmdBuffer = renderWithMotionBlur(camera, ct, motionBlur, offset, time, sampler);
 
-					_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, depthBuffer, mvMatrix, prjMatrix);
+					} else {
+						trnsfrmdBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
+						trnsfrmdBuffer.allocateAsTexture();
+						trnsfrmdBuffer.clear();
 
-					// TODO 親コンポがコラップスしている場合、プリコンポレイヤーのエフェクトはここ？
+						if (withDepthBuffer) {
+							depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
+							_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, depthBuffer, mvMatrix, prjMatrix);
+						} else {
+							_vrSupport.transform(effectedBuffer, trnsfrmdBuffer, null, mvMatrix, prjMatrix);
+						}
+					}
 
-					return new VideoLayerBufferImpl(trnsfrmdBuffer, depthBuffer, _blendMode, opacity);
+					VideoLayerBuffer vlb = new VideoLayerBufferImpl(trnsfrmdBuffer, depthBuffer, _blendMode, opacity);
+					trnsfrmdBuffer = null;
+					depthBuffer = null;
+					return vlb;
 
 				} finally {
-					if (effectedBuffer != null) {
-						effectedBuffer.dispose();
-					}
+					if (depthBuffer != null) depthBuffer.dispose();
+					if (trnsfrmdBuffer != null) trnsfrmdBuffer.dispose();
+					if (effectedBuffer != null) effectedBuffer.dispose();
 				}
 			}
 		};
@@ -418,7 +476,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	private void setupVideoRendererCR(
-			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct) {
+			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct, final MotionBlur motionBlur) {
 
 		final VectorMediaInput input = (VectorMediaInput) getMediaInput();
 		RenderResolution resolution = _vrContext.getRenderResolution();
@@ -429,34 +487,84 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		final double[] prjMatrix = new double[16];
 		createMatrix(camera, ct, null, mvMatrix, prjMatrix);
 
-		final double opacity;
-		if (ct == null) {
-			opacity = _opacity.value(_vrContext) / 100d;
-		} else {
-			opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
-		}
+
+		final Time time = _vrContext.getTime();
 
 		VideoLayerRenderer r = new VideoLayerRenderer() {
 			public VideoLayerBuffer render(boolean withDepthBuffer) {
-				final VideoBuffer rasterBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
-				rasterBuffer.allocateAsTexture();
-				rasterBuffer.clear();
+				// コラップスしているときはここで時刻を再度設定する必要がある。
+				_vrContext.setTime(time);
 
-				// TODO 連続ラスタライズの場合、デプスバッファはここで作成せずに全てのエフェクトが終わった後で計算する。
-				final DepthBuffer depthBuffer = withDepthBuffer ? _vrSupport.createDepthBuffer(camera.getViewportSize()) : null;
+				final double opacity;
+				if (ct == null) {
+					opacity = _opacity.value(_vrContext) / 100d;
+				} else {
+					opacity = _opacity.value(_vrContext) / 100d * ct.getOpacity();
+				}
 
-				_vrContext.saveAndExecute(new WrappedOperation<Object>() {
-					public Object execute() {
-						_vrContext.setTime(calcVideoMediaTime(input));
-						input.rasterize(rasterBuffer, depthBuffer, mvMatrix, prjMatrix);
-						return null;
+				VideoBuffer effectedBuffer = null;
+				VideoBuffer resultBuffer = null;
+				DepthBuffer depthBuffer = null;
+				try {
+					if (withDepthBuffer) {
+						depthBuffer = _vrSupport.createDepthBuffer(camera.getViewportSize());
+						_vrSupport.fillDepth(depthBuffer, mvMatrix, prjMatrix);
 					}
-				});
 
-				// TODO このレイヤーのエフェクト
-				// TODO 親コンポがコラップスしている場合、プリコンポレイヤーのエフェクトはここ？
+					WrappedOperation<VideoBuffer> inputBufferOperation = new WrappedOperation<VideoBuffer>() {
+						public VideoBuffer execute() {
+							VideoBuffer rasterizedBuffer = null;
+							try {
+								if (motionBlur != null && LayerNature.isMotionBlurEnabled(AbstractMediaLayer.this)) {
+									MotionBlurSampler sampler = new MotionBlurSampler() {
+										public void sample(double[] mvMatrix, double[] prjMatrix, VideoBuffer buffer) {
+											input.rasterize(buffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
+										}
+									};
+									rasterizedBuffer = renderWithMotionBlur(camera, ct, motionBlur, null, _vrContext.getTime(), sampler);
 
-				return new VideoLayerBufferImpl(rasterBuffer, depthBuffer, _blendMode, opacity);
+								} else {
+									rasterizedBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
+									rasterizedBuffer.allocateAsTexture();
+									rasterizedBuffer.clear();
+
+									input.rasterize(rasterizedBuffer, mvMatrix, prjMatrix, calcVideoMediaTime(input));
+								}
+
+								VideoBuffer result = rasterizedBuffer;
+								rasterizedBuffer = null;
+								return result;
+
+							} finally {
+								if (rasterizedBuffer != null) rasterizedBuffer.dispose();
+							}
+						}
+					};
+
+					effectedBuffer = _vePipeline.doVideoEffects(
+							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBufferOperation);
+
+					VideoBounds resultBounds = new VideoBounds(camera.getViewportSize());
+					if (effectedBuffer.getBounds().equals(resultBounds)) {
+						resultBuffer = effectedBuffer;
+						effectedBuffer = null;
+					} else {
+						resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), resultBounds);
+						resultBuffer.allocateAsTexture();
+						resultBuffer.clear();
+						_vrSupport.copy(effectedBuffer, resultBuffer);
+					}
+
+					VideoLayerBuffer vlb = new VideoLayerBufferImpl(resultBuffer, depthBuffer, _blendMode, opacity);
+					resultBuffer = null;
+					depthBuffer = null;
+					return vlb;
+
+				} finally {
+					if (depthBuffer != null) depthBuffer.dispose();
+					if (resultBuffer != null) resultBuffer.dispose();
+					if (effectedBuffer != null) effectedBuffer.dispose();
+				}
 			}
 		};
 
@@ -504,6 +612,190 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_vrSupport.pushMatrixAndExecute(operation);
 	}
 
+	private VideoBuffer blendFrames(FrameBlend frameBlend) {
+		if (frameBlend == FrameBlend.NONE) throw new IllegalArgumentException();
+		if (frameBlend != FrameBlend.FRAME_MIX) throw new UnsupportedOperationException();
+
+		MediaInput input = getMediaInput();
+		Time mediaFrameDuration = input.getVideoFrameDuration();
+
+		Time ctxTime = _vrContext.getTime();
+		Time mediaTime0 = calcVideoMediaTime(input);
+		_vrContext.setTime(ctxTime.add(_vrContext.getFrameDuration()));
+		Time mediaTime1 = calcVideoMediaTime(input);
+		_vrContext.setTime(ctxTime);
+
+		Time mediaTimeDiff = mediaTime1.subtract(mediaTime0);
+		double fpsRatio = mediaTimeDiff.toSecond() / mediaFrameDuration.toSecond();
+		if (fpsRatio == 1) {
+			return input.getVideoFrameImage(ctxTime);
+		}
+
+		fpsRatio = Math.abs(fpsRatio);
+
+
+		List<VideoBuffer> buffers = Util.newList();
+		VideoBuffer buf32f = null;
+		try {
+			RenderResolution resolution = _vrContext.getRenderResolution();
+			VideoBounds bounds = resolution.scale(input.getVideoFrameBounds());
+
+			buf32f = _vrSupport.createVideoBuffer(ColorMode.RGBA32_FLOAT, bounds);
+			buf32f.allocateAsTexture();
+			buf32f.clear();
+
+			List<Double> weights = Util.newList();
+			int maxUnits = _glGlobal.getMaxTextureImageUnits();
+
+			if (fpsRatio > 1) {
+				List<Integer> intWeights = Util.newList();
+				int w = (int)Math.round(255/fpsRatio);
+				intWeights.add(w);
+				int rest = 255 - w;
+
+				for (int i = 1; rest > 0; ++i) {
+					double p = 1.17741*2*i/fpsRatio;
+					double q = Math.exp(-p*p/2)/fpsRatio;
+					w = Math.min(rest, 2*(int)Math.round(255*q))/2;
+					if (w > 0) {
+						intWeights.add(w);
+						rest -= 2*w;
+					} else if (rest > 0) {
+						// 端数は中央のフレームに上乗せしてしまう。
+						intWeights.set(0, intWeights.get(0)+rest);
+						rest = 0;
+					}
+				}
+
+				for (int n = intWeights.size(), i = -n+1; i < n; ++i) {
+					Time t = mediaTime0.add(new Time(mediaFrameDuration.timeValue*i, mediaFrameDuration.timeScale));
+
+					buffers.add(input.getVideoFrameImage(t));
+					weights.add(intWeights.get(Math.abs(i))/255.0);
+
+					if (buffers.size() >= maxUnits) {
+						_vrSupport.accumulate(buffers, weights, buf32f);
+						for (VideoBuffer vb : buffers) vb.dispose();
+						buffers.clear();
+						weights.clear();
+					}
+				}
+			} else {
+				long frame = mediaTime0.toFrameNumber(mediaFrameDuration);
+				Time t0, t1;
+				if (mediaTime0.timeValue >= 0) {
+					t0 = Time.fromFrameNumber(frame, mediaFrameDuration);
+					t1 = Time.fromFrameNumber(frame+1, mediaFrameDuration);
+				} else {
+					t0 = Time.fromFrameNumber(frame-1, mediaFrameDuration);
+					t1 = Time.fromFrameNumber(frame, mediaFrameDuration);
+				}
+				long tv0 = mediaTime0.subtract(t0).timeValue;
+				long tv1 = t1.subtract(mediaTime0).timeValue;
+
+				buffers.add(input.getVideoFrameImage(t0));
+				weights.add((double)tv1/(tv0+tv1));
+
+				// maxUnitsが1の場合はあるのか？　無いのなら次のifブロックは不要。
+				if (maxUnits == 1) {
+					_vrSupport.accumulate(buffers, weights, buf32f);
+					buffers.get(0).dispose();
+					buffers.clear();
+					weights.clear();
+				}
+
+				buffers.add(input.getVideoFrameImage(t1));
+				weights.add((double)tv0/(tv0+tv1));
+			}
+			if (!buffers.isEmpty()) {
+				_vrSupport.accumulate(buffers, weights, buf32f);
+			}
+
+			VideoBuffer resultBuffer;
+			if (_vrContext.getColorMode() == ColorMode.RGBA32_FLOAT) {
+				resultBuffer = buf32f;
+				buf32f = null;
+			} else {
+				resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), buf32f.getBounds());
+				resultBuffer.allocateAsTexture();
+				_vrSupport.copy(buf32f, resultBuffer);
+			}
+			return resultBuffer;
+		} finally {
+			for (VideoBuffer vb : buffers) vb.dispose();
+			if (buf32f != null) buf32f.dispose();
+		}
+	}
+
+	private interface MotionBlurSampler {
+		void sample(double[] mvMatrix, double[] prjMatrix, VideoBuffer buffer);
+	}
+
+	private VideoBuffer renderWithMotionBlur(
+			Camera camera, CollapseTransformation ct, MotionBlur motionBlur,
+			Vec2d offset, Time time, MotionBlurSampler sampler) {
+
+		List<VideoBuffer> buffers = Util.newList();
+		VideoBuffer buf = null;
+		VideoBuffer buf32f = null;
+		try {
+			buf32f = _vrSupport.createVideoBuffer(ColorMode.RGBA32_FLOAT, camera.getViewportSize());
+			buf32f.allocateAsTexture();
+			buf32f.clear();
+
+			double shutterAngle = motionBlur.getShutterAngle();
+			double shutterPhase = motionBlur.getShutterPhase();
+			int samples = motionBlur.getSamples();
+			Time frameDuration = _vrContext.getFrameDuration();
+			int maxUnits = _glGlobal.getMaxTextureImageUnits();
+
+			double[] mvMatrix = new double[16];
+			double[] prjMatrix = new double[16];
+
+			for (int i = 0; i < samples; ++i) {
+				double angle = shutterPhase + shutterAngle*i/samples;
+				Time t = time.add(new Time((long)(frameDuration.timeValue*angle/360), frameDuration.timeScale));
+				_vrContext.setTime(t);
+
+				createMatrix(camera, ct, offset, mvMatrix, prjMatrix);
+
+				buf = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
+				buf.allocateAsTexture();
+				buf.clear();
+
+				sampler.sample(mvMatrix, prjMatrix, buf);
+
+				buffers.add(buf);
+				buf = null;
+
+				if (buffers.size() >= maxUnits) {
+					_vrSupport.accumulate(buffers, 1.0/samples, buf32f);
+					for (VideoBuffer vb : buffers) vb.dispose();
+					buffers.clear();
+				}
+			}
+			if (!buffers.isEmpty()) {
+				_vrSupport.accumulate(buffers, 1.0/samples, buf32f);
+			}
+
+			VideoBuffer resultBuffer;
+			if (_vrContext.getColorMode() == ColorMode.RGBA32_FLOAT) {
+				resultBuffer = buf32f;
+				buf32f = null;
+			} else {
+				resultBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), buf32f.getBounds());
+				resultBuffer.allocateAsTexture();
+				_vrSupport.copy(buf32f, resultBuffer);
+			}
+			return resultBuffer;
+
+		} finally {
+			for (VideoBuffer vb : buffers) vb.dispose();
+			if (buf != null) buf.dispose();
+			if (buf32f != null) buf32f.dispose();
+		}
+	}
+
 	private AudioBuffer getTimeRemappedAudioChunk(MediaInput input) {
 		AudioBuffer ab1 = null;
 		AudioBuffer ab2 = null;
