@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -25,7 +25,7 @@ package ch.kuramo.javie.core.internal;
 
 import java.util.Map;
 
-import javax.media.opengl.GL;
+import javax.media.opengl.GL2;
 import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.RenderResolution;
@@ -83,14 +83,14 @@ class CameraImpl implements Camera {
 	private void createMatrix2D() {
 		// TODO この処理は VideoRenderSupport 内に持たすべきでは？
 
-		GL gl = _vrContext.getGL();
+		GL2 gl = _vrContext.getGL().getGL2();
 		GLU glu = _vrContext.getGLU();
 
-		gl.glMatrixMode(GL.GL_PROJECTION);
+		gl.glMatrixMode(GL2.GL_PROJECTION);
 		gl.glLoadIdentity();
 		glu.gluOrtho2D(0, _viewportSize.width, 0, _viewportSize.height);
 
-		gl.glMatrixMode(GL.GL_MODELVIEW);
+		gl.glMatrixMode(GL2.GL_MODELVIEW);
 		gl.glLoadIdentity();
 
 		_vrSupport.getMatrix(_mvMatrix2D, _prjMatrix2D);
@@ -164,14 +164,14 @@ class CameraImpl implements Camera {
 				far = resolution.scale(far);
 
 
-				GL gl = _vrContext.getGL();
+				GL2 gl = _vrContext.getGL().getGL2();
 				GLU glu = _vrContext.getGLU();
 
-				gl.glMatrixMode(GL.GL_PROJECTION);
+				gl.glMatrixMode(GL2.GL_PROJECTION);
 				gl.glLoadIdentity();
 				glu.gluPerspective(fovy, aspect, near, far);
 
-				gl.glMatrixMode(GL.GL_MODELVIEW);
+				gl.glMatrixMode(GL2.GL_MODELVIEW);
 				gl.glLoadIdentity();
 
 				_vrSupport.multCameraMatrix(orientation, rotation, position, pointOfInterest, true);
@@ -199,7 +199,7 @@ class CameraImpl implements Camera {
 		return _compSize.width / (2 * Math.tan(Math.toRadians(fovx/2)));
 	}
 
-	Vec3d getPosition() {
+	public Vec3d getPosition() {
 		return (_cameraLayer != null) ? _cameraLayer.getPosition().value(_vrContext)
 				: new Vec3d(_compSize.width/2.0, _compSize.height/2.0, -getDefaultZoom());
 	}
