@@ -43,7 +43,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 
 	private AnimatableVec3d _position = new AnimatableVec3d(new Vec3d(0, 0, 0));
 
-	private AnimatableVec3d _orientation = new AnimatableVec3d(new Vec3d(0, 0, 0));
+	private AnimatableVec3d _orientation = new AnimatableVec3d(new Vec3d(0, 0, 0), true);
 
 	private AnimatableDouble _rotationX = new AnimatableDouble(0d);
 
@@ -51,11 +51,11 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 
 	private AnimatableDouble _rotationZ = new AnimatableDouble(0d);
 
-	private AnimatableDouble _zoom = new AnimatableDouble(100d);
+	private AnimatableDouble _zoom = new AnimatableDouble(100d, 0d, Double.POSITIVE_INFINITY);
 
-	private AnimatableDouble _near = new AnimatableDouble(1d);
+	private AnimatableDouble _near = new AnimatableDouble(1d, 0d, Double.POSITIVE_INFINITY);
 
-	private AnimatableDouble _far = new AnimatableDouble(1000d);
+	private AnimatableDouble _far = new AnimatableDouble(1000d, 0d, Double.POSITIVE_INFINITY);
 
 
 	public boolean isVideoEnabled() {
@@ -71,6 +71,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setPointOfInterest(AnimatableVec3d pointOfInterest) {
+		pointOfInterest.copyConfigurationFrom(_pointOfInterest);
 		_pointOfInterest = pointOfInterest;
 	}
 
@@ -79,6 +80,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setPosition(AnimatableVec3d position) {
+		position.copyConfigurationFrom(_position);
 		_position = position;
 	}
 
@@ -87,6 +89,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setOrientation(AnimatableVec3d orientation) {
+		orientation.copyConfigurationFrom(_orientation);
 		_orientation = orientation;
 	}
 
@@ -95,6 +98,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setRotationX(AnimatableDouble rotationX) {
+		rotationX.copyConfigurationFrom(_rotationX);
 		_rotationX = rotationX;
 	}
 
@@ -103,6 +107,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setRotationY(AnimatableDouble rotationY) {
+		rotationY.copyConfigurationFrom(_rotationY);
 		_rotationY = rotationY;
 	}
 
@@ -111,6 +116,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setRotationZ(AnimatableDouble rotationZ) {
+		rotationZ.copyConfigurationFrom(_rotationZ);
 		_rotationZ = rotationZ;
 	}
 
@@ -119,6 +125,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setZoom(AnimatableDouble zoom) {
+		zoom.copyConfigurationFrom(_zoom);
 		_zoom = zoom;
 	}
 
@@ -127,6 +134,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setNear(AnimatableDouble near) {
+		near.copyConfigurationFrom(_near);
 		_near = near;
 	}
 
@@ -135,6 +143,7 @@ public class CameraLayerImpl extends AbstractLayer implements CameraLayer {
 	}
 
 	public void setFar(AnimatableDouble far) {
+		far.copyConfigurationFrom(_far);
 		_far = far;
 	}
 
