@@ -36,7 +36,6 @@ import ch.kuramo.javie.core.AnimatableHorizontalAlignment;
 import ch.kuramo.javie.core.AnimatableInteger;
 import ch.kuramo.javie.core.AnimatableString;
 import ch.kuramo.javie.core.AudioBuffer;
-import ch.kuramo.javie.core.DepthBuffer;
 import ch.kuramo.javie.core.ExpressionScope;
 import ch.kuramo.javie.core.HorizontalAlignment;
 import ch.kuramo.javie.core.MediaInput;
@@ -231,11 +230,8 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 			int fontSize = _fontSize.value(_vrContext);
 			FTGLfont font = getFont(psName, fontSize);
 
-			// TODO サイズ0のVideoBoundsを返すとエラーになるので
-			//      暫定的な対処として (1, 1) を返しているが、もっと適切な方法を考える。
-			//      (プレビュー解像度がFULL以外の場合はこの対処ではエラーになるなど、不完全)
 			if (sourceText.length() == 0 || font == null) {
-				return new VideoBounds(1, 1);
+				return new VideoBounds(0, 0);
 			}
 
 			HorizontalAlignment halign = _horizontalAlignment.value(_vrContext);
@@ -312,10 +308,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 			return vb;
 		}
 
-		public void rasterize(
-				VideoBuffer resultBuffer, DepthBuffer depthBuffer,
-				double[] mvMatrix, double[] prjMatrix) {
-
+		public void rasterize(VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime) {
 			RenderResolution resolution = _vrContext.getRenderResolution();
 
 			String psName = _font.value(_vrContext);
@@ -335,7 +328,7 @@ public class TextLayerImpl extends AbstractMediaLayer implements TextLayer {
 				double[][] offsets = calcTextOffsets(font, texts, halign, leading, resolution);
 
 				_vrSupport.renderText(
-						font, fillColor, texts, offsets, resultBuffer, depthBuffer, mvMatrix, prjMatrix);
+						font, fillColor, texts, offsets, resultBuffer, mvMatrix, prjMatrix);
 			}
 		}
 
