@@ -204,7 +204,7 @@ class EffectClassProcessor {
 	}
 
 	private void processProperties() throws ClassNotFoundException, NotFoundException, CannotCompileException, BadBytecode {
-		CtClass enumType = pool.get("java.lang.Enum");
+//		CtClass enumType = pool.get("java.lang.Enum");
 
 		for (CtField cf : ccInterior.getDeclaredFields()) {
 			Property anno = (Property) cf.getAnnotation(Property.class);
@@ -217,13 +217,13 @@ class EffectClassProcessor {
 				CtClass fieldType = cf.getType();
 				String fieldTypeName = fieldType.getName();
 
-				if (fieldTypeName.equals("ch.kuramo.javie.api.plugin.PIAnimatableEnum")) {
+				if (fieldTypeName.equals("ch.kuramo.javie.api.IAnimatableEnum")) {
 					processAnimatableEnumProperty(cf);
-				} else if (fieldTypeName.startsWith("ch.kuramo.javie.api.plugin.PIAnimatable")) {
+				} else if (fieldTypeName.startsWith("ch.kuramo.javie.api.IAnimatable")) {
 					processAnimatableValueProperty(cf);
-				} else if (fieldTypeName.equals("java.lang.String")
-							|| fieldType.subtypeOf(enumType) || fieldType.isPrimitive()) {
-					makeAccessor(fieldTypeName, cf.getName());
+//				} else if (fieldTypeName.equals("java.lang.String")
+//							|| fieldType.subtypeOf(enumType) || fieldType.isPrimitive()) {
+//					makeAccessor(fieldTypeName, cf.getName());
 				} else {
 					// 非サポートの型
 					// TODO ログに警告を出す
@@ -249,7 +249,7 @@ class EffectClassProcessor {
 	private void processAnimatableValueProperty(CtField cf) throws NotFoundException, CannotCompileException {
 		String fieldTypeName = cf.getType().getName();
 		String accessorTypeName = fieldTypeName.replaceFirst(
-				"^ch\\.kuramo\\.javie\\.api\\.plugin\\.PIAnimatable",
+				"^ch\\.kuramo\\.javie\\.api\\.IAnimatable",
 				"ch.kuramo.javie.core.Animatable");
 
 		makeAccessor(accessorTypeName, cf.getName());
@@ -276,7 +276,7 @@ class EffectClassProcessor {
 
 		ClassFile classFile = ccAEnum.getClassFile();
 		SignatureAttribute classSig = new SignatureAttribute(classFile.getConstPool(),
-				String.format("Lch/kuramo/javie/core/AbstractAnimatableEnum<L%1$s;>;Lch/kuramo/javie/api/plugin/PIAnimatableEnum<L%1$s;>;", enumNameSlash));
+				String.format("Lch/kuramo/javie/core/AbstractAnimatableEnum<L%1$s;>;Lch/kuramo/javie/api/IAnimatableEnum<L%1$s;>;", enumNameSlash));
 		classFile.addAttribute(classSig);
 
 		MethodInfo cnstr1Info = cnstr1.getMethodInfo();
@@ -297,7 +297,12 @@ class EffectClassProcessor {
 								typeName, upperCamelCase, interiorName, fieldName);
 		ccExterior.addMethod(CtMethod.make(getter, ccExterior));
 
-		String setter = String.format("public void set%2$s(%1$s value) { ((%3$s) _interior).%4$s = value; }",
+		String setter = String.format("public void set%2$s(%1$s value) {"
+									+ "		if (((%3$s) _interior).%4$s != null) {"
+									+ "			value.copyConfigurationFrom((%1$s) ((%3$s) _interior).%4$s);"
+									+ "		}"
+									+ "		((%3$s) _interior).%4$s = value;"
+									+ "}",
 								typeName, upperCamelCase, interiorName, fieldName);
 		ccExterior.addMethod(CtMethod.make(setter, ccExterior));
 
