@@ -28,8 +28,6 @@ import java.util.Arrays;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
 
-import javax.media.opengl.GL;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -39,8 +37,10 @@ import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.VideoBuffer;
+import ch.kuramo.javie.core.misc.AtiIntelLock;
 import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
@@ -94,6 +94,9 @@ public abstract class PullSourceOutput {
 	@Inject
 	private AudioRenderSupport _arSupport;
 
+	@Inject
+	private GLGlobal _glGlobal;
+
 
 	public void doOutput(final Composition comp, final AudioMode audioMode, File file, ProgressMonitor progMon) {
 		Thread videoThread = new Thread(new Runnable() { public void run() { videoLoop(comp); } });
@@ -122,10 +125,10 @@ public abstract class PullSourceOutput {
 
 
 	protected void videoLoop(Composition comp) {
+		AtiIntelLock atiIntelLock = AtiIntelLock.get(_glGlobal);
+
 		_vrContext.activate();
 		try {
-			GL gl = _vrContext.getGL();
-
 			comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
 
 			while (true) {
@@ -138,17 +141,26 @@ public abstract class PullSourceOutput {
 
 					_vrContext.reset();
 					_vrContext.setRenderResolution(RenderResolution.FULL);
+					_vrContext.setFrameDuration(comp.getFrameDuration());
 					_vrContext.setTime(time);
 
-					vb = comp.renderVideoFrame();
+					atiIntelLock.lock();
+					try {
 
-					// TODO アルファ無し／ストレートアルファ／乗算済みアルファを選択できるよにする
-					_vrSupport.premultiply(vb);
+						vb = comp.renderVideoFrame();
 
-					gl.glFinish();
+						// TODO アルファ無し／ストレートアルファ／乗算済みアルファを選択できるよにする
+						_vrSupport.premultiply(vb);
 
-					finishVideoRequest(request, vb);
-					_videoResponseQueue.put(this);		// 入れる値は何でもよい。
+						// glFinishしておけば finishVideoRequest は AtiIntelLock の外でいいはず。
+						//gl.glFinish();
+
+						finishVideoRequest(request, vb);
+						_videoResponseQueue.put(this);		// 入れる値は何でもよい。
+
+					} finally {
+						atiIntelLock.unlock();
+					}
 
 				} catch (InterruptedException e) {
 					_logger.warn("unexpected interruption", e);
