@@ -26,16 +26,16 @@ package ch.kuramo.javie.core.output;
 import java.io.File;
 import java.util.Arrays;
 
-import javax.media.opengl.GL;
-
 import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Composition;
 import ch.kuramo.javie.core.VideoBuffer;
+import ch.kuramo.javie.core.misc.AtiIntelLock;
 import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
+import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
@@ -55,6 +55,9 @@ public abstract class PushSourceOutput {
 	@Inject
 	private AudioRenderSupport _arSupport;
 
+	@Inject
+	private GLGlobal _glGlobal;
+
 
 	public void doOutput(
 			final Composition comp, final AudioMode audioMode, File file, ProgressMonitor progMon) {
@@ -82,6 +85,8 @@ public abstract class PushSourceOutput {
 
 
 	protected void videoLoop(Composition comp, ProgressMonitor monitor) {
+		AtiIntelLock atiIntelLock = AtiIntelLock.get(_glGlobal);
+
 		Time frameDuration = comp.getFrameDuration();
 		long numFrames = comp.getDuration().toFrameNumber(frameDuration);
 
@@ -89,26 +94,35 @@ public abstract class PushSourceOutput {
 
 		_vrContext.activate();
 		try {
-			GL gl = _vrContext.getGL();
-
 			comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
 
 			for (long i = 0; i < numFrames && !monitor.isCanceled(); ++i) {
 				Time time = Time.fromFrameNumber(i, frameDuration);
 				_vrContext.reset();
 				_vrContext.setRenderResolution(RenderResolution.FULL);
+				_vrContext.setFrameDuration(comp.getFrameDuration());
 				_vrContext.setTime(time);
 
-				VideoBuffer vb = comp.renderVideoFrame();
+				VideoBuffer vb = null;
 				try {
-					// TODO アルファ無し／ストレートアルファ／乗算済みアルファを選択できるよにする
-					_vrSupport.premultiply(vb);
+					atiIntelLock.lock();
+					try {
 
-					gl.glFinish();
+						vb = comp.renderVideoFrame();
 
-					writeVideo(time, vb);
+						// TODO アルファ無し／ストレートアルファ／乗算済みアルファを選択できるよにする
+						_vrSupport.premultiply(vb);
+
+						// glFinishしておけば writeVideo は AtiIntelLock の外でいいはず。
+						//gl.glFinish();
+
+						writeVideo(time, vb);
+
+					} finally {
+						atiIntelLock.unlock();
+					}
 				} finally {
-					vb.dispose();
+					if (vb != null) vb.dispose();
 				}
 
 				monitor.currentWork((int)i);
