@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -37,4 +37,9 @@ public interface AudioRenderContext extends RenderContext {
 
 	void setFrameCount(int count);
 
+
+	int getEvaluationResolution();
+
+	void setEvaluationResolution(int resolution);
+
 }
