@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.core.services;
 
+import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.core.AudioBuffer;
 
@@ -35,6 +36,10 @@ public interface AudioRenderSupport {
 
 	AudioBuffer mix(AudioBuffer ab1, AudioBuffer ab2);
 
-	void amplify(AudioBuffer ab, Vec2d amplitude);
+	void amplify(AudioBuffer ab, IObjectArray<Vec2d> amplitude);
+
+	void clear(AudioBuffer ab);
+
+	void clear(AudioBuffer ab, int frameOffset, int frameCount);
 
 }
