@@ -25,11 +25,13 @@ package ch.kuramo.javie.core.services;
 
 import org.mozilla.javascript.ContextFactory;
 
+import ch.kuramo.javie.api.services.IAntiAliasSupport;
 import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.api.services.IAudioEffectContext;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.core.internal.services.AnimatableValueCollectorImpl;
+import ch.kuramo.javie.core.internal.services.AntiAliasSupportProxy;
 import ch.kuramo.javie.core.internal.services.ArrayPoolsImpl;
 import ch.kuramo.javie.core.internal.services.AudioEffectContextProxy;
 import ch.kuramo.javie.core.internal.services.AudioEffectPipelineImpl;
@@ -43,7 +45,8 @@ import ch.kuramo.javie.core.internal.services.MediaFileInputFactoryImpl;
 import ch.kuramo.javie.core.internal.services.ProjectDecoderImpl;
 import ch.kuramo.javie.core.internal.services.ProjectElementFactoryImpl;
 import ch.kuramo.javie.core.internal.services.ProjectEncoderImpl;
-import ch.kuramo.javie.core.internal.services.ShaderBuilderImpl;
+import ch.kuramo.javie.core.internal.services.RenderBufferPoolImpl;
+import ch.kuramo.javie.core.internal.services.ShaderRegistryImpl;
 import ch.kuramo.javie.core.internal.services.SynchronousTaskThreadImpl;
 import ch.kuramo.javie.core.internal.services.VideoEffectContextProxy;
 import ch.kuramo.javie.core.internal.services.VideoEffectPipelineImpl;
@@ -84,13 +87,13 @@ public class JavieCoreModule extends AbstractModule {
 				.to(EffectRegistryImpl.class)
 				.in(Scopes.SINGLETON);
 
-		ShaderBuilderImpl shaderBuilder = new ShaderBuilderImpl();
+		ShaderRegistryImpl shaderRegistry = new ShaderRegistryImpl();
 
-		bind(ShaderBuilder.class)
-				.toInstance(shaderBuilder);
+		bind(ShaderRegistry.class)
+				.toInstance(shaderRegistry);
 
 		bind(IShaderRegistry.class)
-				.toInstance(shaderBuilder);
+				.toInstance(shaderRegistry);
 
 		bind(VideoRenderContext.class)
 				.to(VideoRenderContextProxy.class)
@@ -124,6 +127,14 @@ public class JavieCoreModule extends AbstractModule {
 				.to(AudioEffectContextProxy.class)
 				.in(Scopes.SINGLETON);
 
+		bind(RenderBufferPool.class)
+				.to(RenderBufferPoolImpl.class)
+				.in(Scopes.SINGLETON);
+
+		bind(IAntiAliasSupport.class)
+				.to(AntiAliasSupportProxy.class)
+				.in(Scopes.SINGLETON);
+
 		bind(FontList.class)
 				.to(FontListImpl.class)
 				.in(Scopes.SINGLETON);
