@@ -24,6 +24,7 @@
 package ch.kuramo.javie.core.services;
 
 import java.util.Collection;
+import java.util.List;
 
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.ColorMode;
@@ -67,9 +68,7 @@ public interface VideoRenderSupport {
 
 	void fill(VideoBuffer videoBuffer, Color color);
 
-	void fillRectCR(
-			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
-			double[] mvMatrix, double[] prjMatrix, Size2i size, Color color);
+	void fillRectCR(VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Size2i size, Color color);
 
 	void trackMatte(
 			VideoBuffer matteBuffer, VideoBuffer fillBuffer, VideoBuffer resultBuffer,
@@ -81,6 +80,8 @@ public interface VideoRenderSupport {
 
 	void premultiply(VideoBuffer vb);
 
+	void copy(VideoBuffer src, VideoBuffer dst);
+
 
 	<T> T pushMatrixAndExecute(WrappedOperation<T> operation);
 
@@ -112,12 +113,17 @@ public interface VideoRenderSupport {
 
 	void scaleAndFlipVertical(VideoBuffer srcBuffer, VideoBuffer resultBuffer, double scale);
 
+	void accumulate(List<VideoBuffer> srcBuffers, List<Double> weights, VideoBuffer dstBuffer);
+
+	void accumulate(List<VideoBuffer> srcBuffers, double weight, VideoBuffer dstBuffer);
+
+	void fillDepth(DepthBuffer depthBuffer, double[] mvMatrix, double[] prjMatrix);
+
+
 	void renderText(FTGLfont font, Color fillColor, String[] texts, double[][] offsets, VideoBuffer resultBuffer);
 
 	void renderText(
-			FTGLfont font, Color fillColor,
-			String[] texts, double[][] offsets,
-			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
-			double[] mvMatrix, double[] prjMatrix);
+			FTGLfont font, Color fillColor, String[] texts, double[][] offsets,
+			VideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix);
 
 }
