@@ -509,6 +509,7 @@
 
 -(OSStatus) audioChunkFromTime:(QTTime)time
 						buffer:(void*)buffer
+						offset:(long)offset
 					frameCount:(long)frameCount
 {
 	if (mAudioExtraction == NULL) {
@@ -531,11 +532,13 @@
 		return error;
 	}
 	
+	char* p = (char*)buffer + mASBD.mBytesPerFrame * offset;
+	
 	AudioBufferList bufList;
 	bufList.mNumberBuffers = 1;
 	bufList.mBuffers[0].mNumberChannels = mASBD.mChannelsPerFrame;
 	bufList.mBuffers[0].mDataByteSize = mASBD.mBytesPerFrame * frameCount;
-	bufList.mBuffers[0].mData = buffer;
+	bufList.mBuffers[0].mData = p;
 	
 	UInt32 flags;
 	UInt32 filledFrames = frameCount;
@@ -549,7 +552,7 @@
 	if (filledFrames < frameCount) {
 		UInt32 filledBytes = filledFrames * mASBD.mBytesPerFrame;
 		UInt32 restBytes = (frameCount - filledFrames) * mASBD.mBytesPerFrame;
-		memset((char*)buffer + filledBytes, 0, restBytes);
+		memset(p + filledBytes, 0, restBytes);
 	}
 	
 	return noErr;
