@@ -23,6 +23,7 @@
 
 #include "StdAfx.h"
 #include "DirectShowInput.h"
+#include <MMReg.h>
 
 
 #define RELEASE(p)						do { if (p) { p->Release(); p = NULL; } } while (false)
@@ -368,6 +369,7 @@ HRESULT VideoInput::FrameImageAtTime(LONGLONG time, void* buffer)
 
 AudioInput::AudioInput()
 	: InputBase(),
+	  mSampleRate(0), mSampleSizeInBits(0), mChannels(0), mFloat(false),
 	  mBuffer(NULL), mRestSize(0)
 {
 }
@@ -392,20 +394,44 @@ HRESULT AudioInput::InitWithFile(LPCWSTR file)
 void AudioInput::GetMediaType(CMediaType* mediaType)
 {
 	mediaType->SetType(&MEDIATYPE_Audio);
-	mediaType->SetSubtype(&MEDIASUBTYPE_PCM);
+//	mediaType->SetSubtype(&MEDIASUBTYPE_PCM);
 	mediaType->SetFormatType(&FORMAT_WaveFormatEx);
 }
 
 HRESULT AudioInput::ConnectSourceToGrabber(IBaseFilter* source, IBaseFilter* grabber)
 {
-	RETURN_HRESULT_IF_FAILED(
-		Connect(source, grabber));
+	HRESULT hr;
+	IPin* inPin = NULL;
+	CMediaType mt, audioMt(&MEDIATYPE_Audio);
 
+	BAIL_IF_FAILED(bail,
+		hr = Connect(source, grabber));
 
-	// TODO サンプルレートなどの変換が必要な場合
+	inPin = GetInPin(grabber);
+	BAIL_IF_FAILED(bail,
+		hr = (inPin != NULL) ? S_OK : E_FAIL);
 
+	BAIL_IF_FAILED(bail,
+		hr = inPin->ConnectionMediaType(&mt));
 
-	return S_OK;
+	audioMt.SetSubtype(&MEDIASUBTYPE_PCM);
+	if (!mt.MatchesPartial(&audioMt)) {
+		audioMt.SetSubtype(&MEDIASUBTYPE_IEEE_FLOAT);
+		if (!mt.MatchesPartial(&audioMt)) {
+			hr = E_FAIL;
+			goto bail;
+		}
+	}
+
+	WAVEFORMATEX* wfx = (WAVEFORMATEX*)mt.Format();
+	mSampleRate = wfx->nSamplesPerSec;
+	mSampleSizeInBits = wfx->wBitsPerSample;
+	mChannels = wfx->nChannels;
+	mFloat = (wfx->wFormatTag == WAVE_FORMAT_IEEE_FLOAT);
+
+bail:
+	RELEASE(inPin);
+	return hr;
 }
 
 HRESULT AudioInput::BufferCB(void* buffer, long bufferSize)
