@@ -25,7 +25,7 @@ package ch.kuramo.javie.effects.blurSharpen;
 
 import java.util.Arrays;
 
-import javax.media.opengl.GL;
+import javax.media.opengl.GL2;
 import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.IAnimatableBoolean;
@@ -95,6 +95,9 @@ public class BoxBlur {
 
 
 		VideoBounds bounds = context.getPreviousBounds();
+		if (bounds.isEmpty()) {
+			return bounds;
+		}
 
 		for (int i = 0; i < iterations; ++i) {
 			bounds = calcVideoBounds(bounds, blur, horz, vert, fast);
@@ -154,6 +157,9 @@ public class BoxBlur {
 
 
 		IVideoBuffer buffer = context.doPreviousEffect();
+		if (buffer.getBounds().isEmpty()) {
+			return buffer;
+		}
 
 		for (int i = 0; i < iterations; ++i) {
 			buffer = doBoxBlur(buffer, blur, repeatEdgePixels, horz, vert, fast);
@@ -166,7 +172,7 @@ public class BoxBlur {
 			IVideoBuffer input, double blur, boolean repeatEdgePixels,
 			boolean horz, boolean vert, boolean fast) {
 
-		GL gl = context.getGL();
+		GL2 gl = context.getGL().getGL2();
 		GLU glu = context.getGLU();
 
 		VideoBounds inputBounds = input.getBounds();
