@@ -23,7 +23,7 @@
 
 package ch.kuramo.javie.effects.blurSharpen;
 
-import javax.media.opengl.GL;
+import javax.media.opengl.GL2;
 import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.IAnimatableBoolean;
@@ -87,6 +87,9 @@ public class GaussianBlur {
 
 
 		VideoBounds bounds = context.getPreviousBounds();
+		if (bounds.isEmpty()) {
+			return bounds;
+		}
 
 		int sampleRatio = 1;
 		if (fast) {
@@ -130,11 +133,14 @@ public class GaussianBlur {
 		blur = context.getRenderResolution().scale(blur);
 
 
-		GL gl = context.getGL();
+		GL2 gl = context.getGL().getGL2();
 		GLU glu = context.getGLU();
 
 		IVideoBuffer input = context.doPreviousEffect();
 		VideoBounds inputBounds = input.getBounds();
+		if (inputBounds.isEmpty()) {
+			return input;
+		}
 
 		int sampleRatio = 1;
 		if (fast) {
