@@ -23,8 +23,7 @@
 
 package ch.kuramo.javie.effects.distort;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.glu.GLU;
+import javax.media.opengl.GL2;
 
 import ch.kuramo.javie.api.IAnimatableDouble;
 import ch.kuramo.javie.api.IAnimatableEnum;
@@ -32,10 +31,8 @@ import ch.kuramo.javie.api.IShaderProgram;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
-import ch.kuramo.javie.api.annotations.GLProgram;
-import ch.kuramo.javie.api.annotations.GLShader;
 import ch.kuramo.javie.api.annotations.Property;
-import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
+import ch.kuramo.javie.api.annotations.ShaderSource;
 import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
@@ -45,8 +42,7 @@ import com.google.inject.Inject;
 @Effect(id="ch.kuramo.javie.PolarCoordinates", category=Effect.DISTORT)
 public class PolarCoordinates {
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] RECT_TO_POLAR = {
 		"uniform sampler2DRect texture;",
 		"uniform vec2 center;",
@@ -67,8 +63,7 @@ public class PolarCoordinates {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] POLAR_TO_RECT = {
 		"uniform sampler2DRect texture;",
 		"uniform vec2 center;",
@@ -116,73 +111,77 @@ public class PolarCoordinates {
 	}
 
 	public IVideoBuffer doVideoEffect() {
-		double interp = context.value(this.interpolation)/100;
+		final double interp = context.value(this.interpolation)/100;
 		if (interp == 0) {
 			return null;
 		}
 
-		TypeOfConversion type = context.value(this.typeOfConversion);
-		IShaderProgram program = (type == TypeOfConversion.RECT_TO_POLAR)
+		final TypeOfConversion type = context.value(this.typeOfConversion);
+		final IShaderProgram program = (type == TypeOfConversion.RECT_TO_POLAR)
 				? rectToPolarProgram : polarToRectProgram;
 
-		IVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer input = null;
 		IVideoBuffer buffer = null;
 		try {
+			input = context.doPreviousEffect();
 			VideoBounds bounds = input.getBounds();
-			int w = bounds.width;
-			int h = bounds.height;
+			if (bounds.isEmpty()) {
+				IVideoBuffer output = input;
+				input = null;
+				return output;
+			}
+
+			final int w = bounds.width;
+			final int h = bounds.height;
 
 			buffer = context.createVideoBuffer(bounds);
 
-			GL gl = context.getGL();
-			GLU glu = context.getGLU();
+			final GL2 gl = context.getGL().getGL2();
 
-			VideoEffectUtil.ortho2D(gl, glu, w, h);
+			VideoEffectUtil.ortho2D(gl, context.getGLU(), w, h);
 
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, buffer.getTexture(), 0);
-			gl.glDrawBuffer(GL.GL_COLOR_ATTACHMENT0_EXT);
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, buffer.getTexture(), 0);
+			gl.glDrawBuffer(GL2.GL_COLOR_ATTACHMENT0);
 
-			gl.glActiveTexture(GL.GL_TEXTURE0);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, input.getTexture());
+			gl.glActiveTexture(GL2.GL_TEXTURE0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, input.getTexture());
 
-			synchronized (program) {
-				gl.glUseProgram(program.getProgram());
-				gl.glUniform1i(program.getUniformLocation("texture"), 0);
-				gl.glUniform2f(program.getUniformLocation("center"), w/2f, h/2f);
-				gl.glUniform1f(program.getUniformLocation("radians_per_px"), (float)Math.toRadians(360.0/w));
-				if (type == TypeOfConversion.POLAR_TO_RECT) {
-					gl.glUniform1f(program.getUniformLocation("maxRadius_div_h"), (float)(Math.sqrt(w*w+h*h)*0.5/h));
+			program.useProgram(new Runnable() {
+				public void run() {
+					gl.glUniform1i(program.getUniformLocation("texture"), 0);
+					gl.glUniform2f(program.getUniformLocation("center"), w/2f, h/2f);
+					gl.glUniform1f(program.getUniformLocation("radians_per_px"), (float)Math.toRadians(360.0/w));
+					if (type == TypeOfConversion.POLAR_TO_RECT) {
+						gl.glUniform1f(program.getUniformLocation("maxRadius_div_h"), (float)(Math.sqrt(w*w+h*h)*0.5/h));
+					}
+					gl.glUniform1f(program.getUniformLocation("interp"), (float)interp);
+
+					gl.glBegin(GL2.GL_QUADS);
+					gl.glTexCoord2f(0, 0);
+					gl.glVertex2f(0, 0);
+					gl.glTexCoord2f(w, 0);
+					gl.glVertex2f(w, 0);
+					gl.glTexCoord2f(w, h);
+					gl.glVertex2f(w, h);
+					gl.glTexCoord2f(0, h);
+					gl.glVertex2f(0, h);
+					gl.glEnd();
 				}
-				gl.glUniform1f(program.getUniformLocation("interp"), (float)interp);
+			});
 
-				gl.glBegin(GL.GL_QUADS);
-				gl.glTexCoord2f(0, 0);
-				gl.glVertex2f(0, 0);
-				gl.glTexCoord2f(w, 0);
-				gl.glVertex2f(w, 0);
-				gl.glTexCoord2f(w, h);
-				gl.glVertex2f(w, h);
-				gl.glTexCoord2f(0, h);
-				gl.glVertex2f(0, h);
-				gl.glEnd();
+			gl.glActiveTexture(GL2.GL_TEXTURE0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
 
-				gl.glFinish();
-				gl.glUseProgram(0);
-			}
-
-			gl.glActiveTexture(GL.GL_TEXTURE0);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
-
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
 
 			IVideoBuffer output = buffer;
 			buffer = null;
 			return output;
 
 		} finally {
-			input.dispose();
+			if (input != null) input.dispose();
 			if (buffer != null) buffer.dispose();
 		}
 	}
