@@ -23,8 +23,7 @@
 
 package ch.kuramo.javie.effects.keying;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.glu.GLU;
+import javax.media.opengl.GL2;
 
 import ch.kuramo.javie.api.IAnimatableBoolean;
 import ch.kuramo.javie.api.IAnimatableDouble;
@@ -86,69 +85,44 @@ public abstract class BlueGreenScreenKeyBase {
 			}
 		}
 
-		IVideoBuffer input = context.doPreviousEffect();
+		final float ft = (float) t;
+		final float ftc = (float) t_minus_c;
+
+		IVideoBuffer input = null;
 		IVideoBuffer buf = null;
 		try {
+			input = context.doPreviousEffect();
 			VideoBounds bounds = input.getBounds();
-			int w = bounds.width;
-			int h = bounds.height;
+			if (bounds.isEmpty()) {
+				IVideoBuffer output = input;
+				input = null;
+				return output;
+			}
+
+			final int w = bounds.width;
+			final int h = bounds.height;
 
 			buf = context.createVideoBuffer(bounds);
 
-			GL gl = context.getGL();
-			GLU glu = context.getGLU();
+			final GL2 gl = context.getGL().getGL2();
 
-			VideoEffectUtil.ortho2D(gl, glu, w, h);
+			VideoEffectUtil.ortho2D(gl, context.getGLU(), w, h);
 
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, buf.getTexture(), 0);
-			gl.glDrawBuffer(GL.GL_COLOR_ATTACHMENT0_EXT);
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, buf.getTexture(), 0);
+			gl.glDrawBuffer(GL2.GL_COLOR_ATTACHMENT0);
 
-			gl.glActiveTexture(GL.GL_TEXTURE0);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, input.getTexture());
+			gl.glActiveTexture(GL2.GL_TEXTURE0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, input.getTexture());
 
-			IShaderProgram program = mask ? maskOnlyProgram : keyingProgram;
-			synchronized (program) {
-				gl.glUseProgram(program.getProgram());
-				gl.glUniform1i(program.getUniformLocation("texture"), 0);
-				gl.glUniform1f(program.getUniformLocation("threshold"), (float) t);
-				gl.glUniform1f(program.getUniformLocation("t_minus_c"), (float) t_minus_c);
+			final IShaderProgram program1 = mask ? maskOnlyProgram : keyingProgram;
+			program1.useProgram(new Runnable() {
+				public void run() {
+					gl.glUniform1i(program1.getUniformLocation("texture"), 0);
+					gl.glUniform1f(program1.getUniformLocation("threshold"), ft);
+					gl.glUniform1f(program1.getUniformLocation("t_minus_c"), ftc);
 
-				gl.glBegin(GL.GL_QUADS);
-				gl.glTexCoord2f(0, 0);
-				gl.glVertex2f(0, 0);
-				gl.glTexCoord2f(w, 0);
-				gl.glVertex2f(w, 0);
-				gl.glTexCoord2f(w, h);
-				gl.glVertex2f(w, h);
-				gl.glTexCoord2f(0, h);
-				gl.glVertex2f(0, h);
-				gl.glEnd();
-	
-				gl.glFinish();
-				gl.glUseProgram(0);
-			}
-
-			switch (sm) {
-				case LOW:  program = smoothingLowProgram; break;
-				case HIGH: program = smoothingHighProgram; break;
-				default:   program = null; break;
-			}
-
-			if (program != null) {
-				IVideoBuffer tmp = input;
-				input = buf;
-				buf = tmp;
-
-				gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-						GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, buf.getTexture(), 0);
-				gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, input.getTexture());
-
-				synchronized (program) {
-					gl.glUseProgram(program.getProgram());
-					gl.glUniform1i(program.getUniformLocation("texture"), 0);
-
-					gl.glBegin(GL.GL_QUADS);
+					gl.glBegin(GL2.GL_QUADS);
 					gl.glTexCoord2f(0, 0);
 					gl.glVertex2f(0, 0);
 					gl.glTexCoord2f(w, 0);
@@ -158,24 +132,55 @@ public abstract class BlueGreenScreenKeyBase {
 					gl.glTexCoord2f(0, h);
 					gl.glVertex2f(0, h);
 					gl.glEnd();
-		
-					gl.glFinish();
-					gl.glUseProgram(0);
 				}
+			});
+
+			final IShaderProgram program2;
+			switch (sm) {
+				case LOW:  program2 = smoothingLowProgram; break;
+				case HIGH: program2 = smoothingHighProgram; break;
+				default:   program2 = null; break;
 			}
 
-			gl.glActiveTexture(GL.GL_TEXTURE0);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
+			if (program2 != null) {
+				IVideoBuffer tmp = input;
+				input = buf;
+				buf = tmp;
 
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
+				gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+						GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, buf.getTexture(), 0);
+				gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, input.getTexture());
+
+				program2.useProgram(new Runnable() {
+					public void run() {
+						gl.glUniform1i(program2.getUniformLocation("texture"), 0);
+
+						gl.glBegin(GL2.GL_QUADS);
+						gl.glTexCoord2f(0, 0);
+						gl.glVertex2f(0, 0);
+						gl.glTexCoord2f(w, 0);
+						gl.glVertex2f(w, 0);
+						gl.glTexCoord2f(w, h);
+						gl.glVertex2f(w, h);
+						gl.glTexCoord2f(0, h);
+						gl.glVertex2f(0, h);
+						gl.glEnd();
+					}
+				});
+			}
+
+			gl.glActiveTexture(GL2.GL_TEXTURE0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
+
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
 
 			IVideoBuffer output = buf;
 			buf = null;
 			return output;
 
 		} finally {
-			input.dispose();
+			if (input != null) input.dispose();
 			if (buf != null) buf.dispose();
 		}
 	}
