@@ -23,14 +23,11 @@
 
 package ch.kuramo.javie.effects.keying;
 
-import ch.kuramo.javie.api.annotations.GLProgram;
-import ch.kuramo.javie.api.annotations.GLShader;
-import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
+import ch.kuramo.javie.api.annotations.ShaderSource;
 
 public class KeyingShaders {
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] BLUE_SCREEN_KEY = {
 		"uniform sampler2DRect texture;",
 		"uniform float threshold;",
@@ -46,8 +43,7 @@ public class KeyingShaders {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] BLUE_SCREEN_KEY_MASK_ONLY = {
 		"uniform sampler2DRect texture;",
 		"uniform float threshold;",
@@ -62,8 +58,7 @@ public class KeyingShaders {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] GREEN_SCREEN_KEY = {
 		"uniform sampler2DRect texture;",
 		"uniform float threshold;",
@@ -79,8 +74,7 @@ public class KeyingShaders {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] GREEN_SCREEN_KEY_MASK_ONLY = {
 		"uniform sampler2DRect texture;",
 		"uniform float threshold;",
@@ -95,8 +89,7 @@ public class KeyingShaders {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] SMOOTHING_LOW = {
 		"uniform sampler2DRect texture;",
 		"",
@@ -120,8 +113,7 @@ public class KeyingShaders {
 		"}"
 	};
 
-	@GLShader(ShaderType.FRAGMENT_SHADER)
-	@GLProgram
+	@ShaderSource
 	public static final String[] SMOOTHING_HIGH = {
 		"uniform sampler2DRect texture;",
 		"",
