@@ -23,7 +23,7 @@
 
 package ch.kuramo.javie.effects.utility;
 
-import javax.media.opengl.GL;
+import javax.media.opengl.GL2;
 import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.IAnimatableInteger;
@@ -96,32 +96,38 @@ public class ChangeBounds {
 			return input;
 		}
 
+		if (newBounds.isEmpty()) {
+			input.dispose();
+			return context.createVideoBuffer(newBounds);
+		}
+
+
 		IVideoBuffer buffer = context.createVideoBuffer(newBounds);
 		try {
-			GL gl = context.getGL();
+			GL2 gl = context.getGL().getGL2();
 			GLU glu = context.getGLU();
 
 			VideoEffectUtil.clearTexture(buffer, gl);
 
 			VideoEffectUtil.ortho2D(gl, glu, newBounds.width, newBounds.height);
 
-			gl.glMatrixMode(GL.GL_MODELVIEW);
+			gl.glMatrixMode(GL2.GL_MODELVIEW);
 			gl.glTranslatef(left, top, 0);
 
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, buffer.getTexture(), 0);
-			gl.glDrawBuffer(GL.GL_COLOR_ATTACHMENT0_EXT);
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, buffer.getTexture(), 0);
+			gl.glDrawBuffer(GL2.GL_COLOR_ATTACHMENT0);
 
-			gl.glActiveTexture(GL.GL_TEXTURE0);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, input.getTexture());
-			gl.glEnable(GL.GL_TEXTURE_RECTANGLE_EXT);
+			gl.glActiveTexture(GL2.GL_TEXTURE0);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, input.getTexture());
+			gl.glEnable(GL2.GL_TEXTURE_RECTANGLE);
 
 			gl.glColor4f(1, 1, 1, 1);
 
 			int w = oldBounds.width;
 			int h = oldBounds.height;
 
-			gl.glBegin(GL.GL_QUADS);
+			gl.glBegin(GL2.GL_QUADS);
 			gl.glTexCoord2f(0, 0);
 			gl.glVertex2f(0, 0);
 			gl.glTexCoord2f(w, 0);
@@ -132,11 +138,11 @@ public class ChangeBounds {
 			gl.glVertex2f(0, h);
 			gl.glEnd();
 
-			gl.glDisable(GL.GL_TEXTURE_RECTANGLE_EXT);
-			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
+			gl.glDisable(GL2.GL_TEXTURE_RECTANGLE);
+			gl.glBindTexture(GL2.GL_TEXTURE_RECTANGLE, 0);
 
-			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
-					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
+			gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+					GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_RECTANGLE, 0, 0);
 
 			IVideoBuffer output = buffer;
 			buffer = null;
